@@ -1,5 +1,5 @@
 /*
-                     Clipboard IO and Clipboard Browser
+		     Clipboard IO and Clipboard Browser
  */
 
 #ifndef CLIPBOARD_H
@@ -8,12 +8,8 @@
 #include <sys/types.h>
 #include <gtk/gtk.h>
 
-#ifndef gbool
-# define gbool	gboolean
-#endif
-
-extern u_int8_t *ClipboardFetchBinary(gint *length);
-extern gint ClipboardPutBinary(const u_int8_t *data, gint length);
+extern guint8 *ClipboardFetchBinary(gint *length);
+extern gint ClipboardPutBinary(const guint8 *data, gint length);
 
 extern gint ClipboardBrowserInit(void);
 extern void ClipboardBrowserMap(void);
