@@ -1,5 +1,5 @@
 /*
-                            Color Selection Dialog
+			    Color Selection Dialog
  */
 
 #ifndef CSD_H
@@ -8,7 +8,7 @@
 #include <gtk/gtk.h>
 
 /*
- *	Color selection dialog color structure:
+ *	Color Selection Dialog Color structure:
  */
 typedef struct {
 
@@ -18,12 +18,13 @@ typedef struct {
 
 
 extern gint CSDInit(void);
+extern void CSDSetStyle(GtkRcStyle *rc_style);
 extern void CSDSetTransientFor(GtkWidget *w);
 extern gboolean CSDIsQuery(void);
 extern void CSDBreakQuery(void);
 extern gboolean CSDGetResponse(
-        const gchar *title,
-        const gchar *ok_label, const gchar *cancel_label,
+	const gchar *title,
+	const gchar *ok_label, const gchar *cancel_label,
 	csd_color_struct *start_color,
 	csd_color_struct **color_rtn,
 	gpointer client_data,
