@@ -1,5 +1,5 @@
 /*
-              VMA Editor - HeightField Primitive Handling
+	      VMA Editor - HeightField Primitive Handling
  */
 
 #ifndef EDITORHF_H
@@ -12,20 +12,20 @@
 
 
 extern void EditorHFPrimitiveRealize(
-        ma_editor_struct *editor,
-        mp_heightfield_load_struct *mp_heightfield_load,
-        gbool rerealize
+	ma_editor_struct *editor,
+	mp_heightfield_load_struct *mp_heightfield_load,
+	gbool rerealize
 );
 extern void EditorHFPrimitiveUnrealize(
-        ma_editor_struct *editor,
-        mp_heightfield_load_struct *mp_heightfield_load
+	ma_editor_struct *editor,
+	mp_heightfield_load_struct *mp_heightfield_load
 );
 
 extern void EditorHFDialogMap(
-        ma_editor_struct *editor,
-        void *p         /* If NULL, then implies create. */
+	ma_editor_struct *editor,
+	void *p         /* If NULL, then implies create. */
 );
-extern void EditorHFDialogBrowseCB(void *widget, void *data);
+extern void EditorHFDialogBrowseCB(GtkWidget *widget, gpointer data);
 extern void EditorHFDialogOKCB(void *idialog, void *data);
 extern void EditorHFDialogApplyCB(void *idialog, void *data);
 extern void EditorHFDialogCancelCB(void *idialog, void *data);
