@@ -53,7 +53,7 @@ gint EditorDoExport(ma_editor_struct *editor);
 gint EditorDoImport(ma_editor_struct *editor)
 {
 	gint i, n, status;
-        fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
+	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
 	gint total_ftypes = 0;
 	gchar **path_rtn;
 	gint path_total_rtns;
@@ -68,8 +68,8 @@ gint EditorDoImport(ma_editor_struct *editor)
 	if(!editor->initialized || editor->processing)
 	    return(-1);
 
-        if(VMAWriteProtectCheck(editor))
-            return(-1);
+	if(VMAWriteProtectCheck(editor))
+	    return(-1);
 
 	core_ptr = (vma_core_struct *)editor->core_ptr;
 	if(core_ptr == NULL)
@@ -93,7 +93,7 @@ gint EditorDoImport(ma_editor_struct *editor)
 	    if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
 		continue;
 
-	    /* Skip plug-ins that are busy processing. */
+	    /* Skip plug-ins that are busy processing */
 	    if(plugin_ptr->processing)
 		continue;
 
@@ -109,7 +109,7 @@ gint EditorDoImport(ma_editor_struct *editor)
 		FileBrowserTypeListNew(
 		    &ftype, &total_ftypes,
 		    plugin_ptr->import_ftype_ext[n],
-                    plugin_ptr->import_ftype_name[n]
+		    plugin_ptr->import_ftype_name[n]
 		);
 	    }
 	}
@@ -122,13 +122,13 @@ gint EditorDoImport(ma_editor_struct *editor)
 	     */
 	}
 
-	/* Query user for file. */
+	/* Query user for file */
 	filename = NULL;
 	extension = NULL;
 	FileBrowserSetTransientFor(editor->toplevel);
 	status = FileBrowserGetResponse(
 	    "Import Model Data", "Import", "Cancel",
-	    dname.fb_last_models,		/* Path. */
+	    dname.fb_last_models,		/* Path */
 	    ftype, total_ftypes,
 	    &path_rtn, &path_total_rtns,
 	    &ftype_rtn
@@ -146,14 +146,14 @@ gint EditorDoImport(ma_editor_struct *editor)
 	    }
 	}
 
-	/* Get extension if any. */
+	/* Get extension if any */
 	if(ftype_rtn != NULL)
 	{
 	    if(ftype_rtn->ext != NULL)
 		extension = g_strdup(ftype_rtn->ext);
 	}
 
-	/* Deallocate all file types. */
+	/* Deallocate all file types */
 	FileBrowserDeleteTypeList(ftype, total_ftypes);
 	ftype = NULL;
 	total_ftypes = 0;
@@ -178,7 +178,7 @@ gint EditorDoImport(ma_editor_struct *editor)
 	/* Selected file extension type suggests to auto detect? */
 	if((*extension) == '*')
 	{
-	    /* Get file name extension from selected file. */
+	    /* Get file name extension from selected file */
 	    const char *filename_extension = strrchr(filename, '.');
 	    if(filename_extension == NULL)
 		filename_extension = filename;
@@ -186,16 +186,16 @@ gint EditorDoImport(ma_editor_struct *editor)
 	    for(i = 0; i < core_ptr->total_plugins; i++)
 	    {
 		plugin_ptr = core_ptr->plugin[i];
-                if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
-                    continue;
+		if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
+		    continue;
 
-                /* Skip plug-ins that are busy processing. */
-                if(plugin_ptr->processing)
-                    continue;
+		/* Skip plug-ins that are busy processing */
+		if(plugin_ptr->processing)
+		    continue;
 
-                /* Does not support import file type check? */
-                if(plugin_ptr->import_fcheck == NULL)
-                    continue;
+		/* Does not support import file type check? */
+		if(plugin_ptr->import_fcheck == NULL)
+		    continue;
 
 		plugin_ptr->processing = 1;
 		status = plugin_ptr->import_fcheck(
@@ -216,20 +216,20 @@ gint EditorDoImport(ma_editor_struct *editor)
 	}
 	else
 	{
-	    /* Match by extension. */
-            for(i = 0; i < core_ptr->total_plugins; i++)
-            {
-                plugin_ptr = core_ptr->plugin[i];
-                if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
-                    continue;
+	    /* Match by extension */
+	    for(i = 0; i < core_ptr->total_plugins; i++)
+	    {
+		plugin_ptr = core_ptr->plugin[i];
+		if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
+		    continue;
 
-                /* Skip plug-ins that are busy processing. */
-                if(plugin_ptr->processing)
-                    continue;
+		/* Skip plug-ins that are busy processing */
+		if(plugin_ptr->processing)
+		    continue;
 
-                /* Does not support import? */
-                if(plugin_ptr->import == NULL)
-                    continue;
+		/* Does not support import? */
+		if(plugin_ptr->import == NULL)
+		    continue;
 
 		/* Supports import, check through all supported file
 		 * extension types set on the plug-in for any matches.
@@ -252,12 +252,12 @@ gint EditorDoImport(ma_editor_struct *editor)
 		}
 		else
 		{
-		    /* Got matching extension. */
+		    /* Got matching extension */
 		    break;
 		}
 	    }
-            if(i >= core_ptr->total_plugins)
-                plugin_ptr = NULL;
+	    if(i >= core_ptr->total_plugins)
+		plugin_ptr = NULL;
 	}
 
 	/* Found plug-in that supports this extension type, supports
@@ -265,13 +265,13 @@ gint EditorDoImport(ma_editor_struct *editor)
 	 */
 	if((plugin_ptr == NULL) ? 0 :
 	    (plugin_ptr->import != NULL) &&
-            !plugin_ptr->processing
+	    !plugin_ptr->processing
 	)
 	{
 	    vpi_op_import_struct v;
 
 
-	    /* Set up import operation value structure. */
+	    /* Set up import operation value structure */
 	    v.flags = (VPI_OP_IMPORT_EDITOR_ID |
 		VPI_OP_IMPORT_FILENAME | VPI_OP_IMPORT_HEADER |
 		VPI_OP_IMPORT_MODELS
@@ -284,35 +284,35 @@ gint EditorDoImport(ma_editor_struct *editor)
 	    v.editor_id = i;
 	    v.filename = g_strdup(filename);
 	    v.mh_item = editor->mh_item;
-            v.total_mh_items = editor->total_mh_items;
-            v.model = editor->model;
-            v.total_models = editor->total_models;
+	    v.total_mh_items = editor->total_mh_items;
+	    v.model = editor->model;
+	    v.total_models = editor->total_models;
 
-	    /* Mark editor and plug-in as processing. */
+	    /* Mark editor and plug-in as processing */
 	    EditorSetBusy(editor);
 /*	    editor->processing = TRUE; */
 	    plugin_ptr->processing = 1;
 
-	    /* Call plug-in's import function. */
+	    /* Call plug-in's import function */
 	    status = plugin_ptr->import(
 		(vpi_id *)plugin_ptr,
 		&v,
 		plugin_ptr->import_data
 	    );
 
-	    /* Mark editor and plug-in as done processing. */
+	    /* Mark editor and plug-in as done processing */
 	    plugin_ptr->processing = 0;
 	    EditorSetReady(editor);
 /*	    editor->processing = FALSE; */
 
-	    /* Deallocate import values structure members. */
+	    /* Deallocate import values structure members */
 	    g_free(v.filename);
 
-            /* Importing counts as change on editor, update has_changes. */
+	    /* Importing counts as change on editor, update has_changes */
 	    if(!editor->has_changes);
 		editor->has_changes = TRUE;
 
-	    /* Update editor and redraw. */
+	    /* Update editor and redraw */
 	    EditorUpdateMenus(editor);
 	    EditorUpdateAllViewMenus(editor);
 	    EditorRedrawAllViews(editor);
@@ -321,11 +321,11 @@ gint EditorDoImport(ma_editor_struct *editor)
 	}
 	else
 	{
-	    /* No plug-in available that supports this format. */
+	    /* No plug-in available that supports this format */
 	    gint len = (80 * 8) + strlen(filename);
 	    gchar *buf;
 
-            VMAStatusBarMessage(editor->sb, "Import failed");
+	    VMAStatusBarMessage(editor->sb, "Import failed");
 
 	    buf = (gchar *)g_malloc((len + 1) * sizeof(gchar));
 	    if(buf != NULL)
@@ -341,31 +341,31 @@ a plug-in that supports this file's format.",
 		    filename
 		);
 
-            CDialogSetTransientFor(editor->toplevel);
-            CDialogGetResponse(
+	    CDialogSetTransientFor(editor->toplevel);
+	    CDialogGetResponse(
 "Import failed!",
 		buf,
 "Importing of different file formats are handled by\n\
 plug-ins. You need to enable or obtain/install\n\
 a plug-in that supports the format in question.",
-                CDIALOG_ICON_ERROR,
-                CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
-                CDIALOG_BTNFLAG_OK
-            );
-            CDialogSetTransientFor(NULL);
+		CDIALOG_ICON_ERROR,
+		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    CDialogSetTransientFor(NULL);
 
 	    g_free(buf);
 	    buf = NULL;
 	}
 
-	/* Record last path. */
+	/* Record last path */
 	VMARecordFBPath(
 	    filename,
 	    dname.fb_last_models,
 	    1
 	);
 
-	/* Deallocate file name and extension. */
+	/* Deallocate file name and extension */
 	g_free(filename);
 	g_free(extension);
 
@@ -391,34 +391,34 @@ a plug-in that supports the format in question.",
  */
 gint EditorDoExport(ma_editor_struct *editor)
 {
-        gint i, n, status;
-        fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-        gint total_ftypes = 0;
-        gchar **path_rtn;
-        gint path_total_rtns;
-        vma_plugin_struct *plugin_ptr;
-        vma_core_struct *core_ptr;
+	gint i, n, status;
+	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
+	gint total_ftypes = 0;
+	gchar **path_rtn;
+	gint path_total_rtns;
+	vma_plugin_struct *plugin_ptr;
+	vma_core_struct *core_ptr;
 	const gchar *last_extension;
-        gchar *filename, *extension;
+	gchar *filename, *extension;
 
 
-        if(editor == NULL)
-            return(-1);
+	if(editor == NULL)
+	    return(-1);
 
-        if(!editor->initialized || editor->processing)
-            return(-1);
+	if(!editor->initialized || editor->processing)
+	    return(-1);
 
-        if(VMAWriteProtectCheck(editor))
-            return(-1);
+	if(VMAWriteProtectCheck(editor))
+	    return(-1);
 
-        core_ptr = (vma_core_struct *)editor->core_ptr;
-        if(core_ptr == NULL)
-            return(-1);
+	core_ptr = (vma_core_struct *)editor->core_ptr;
+	if(core_ptr == NULL)
+	    return(-1);
 
 
-        /* Add the first file extension type to be the previous export
+	/* Add the first file extension type to be the previous export
 	 * type used.
-         */
+	 */
 	last_extension = (const gchar *)VMACFGItemListGetValueS(
 	    option, VMA_CFG_PARM_LAST_EXT_EXPORT
 	);
@@ -428,96 +428,99 @@ gint EditorDoExport(ma_editor_struct *editor)
 		last_extension, "Previous Type"
 	    );
 
-        /* Itterate through all plug-ins on core structure, gathering
-         * file extension types.
-         */
-        for(i = 0; i < core_ptr->total_plugins; i++)
-        {
-            plugin_ptr = core_ptr->plugin[i];
-            if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
-                continue;
+	/* Itterate through all plug-ins on core structure, gathering
+	 * file extension types.
+	 */
+	for(i = 0; i < core_ptr->total_plugins; i++)
+	{
+	    plugin_ptr = core_ptr->plugin[i];
+	    if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
+		continue;
 
-            /* Skip plug-ins that are busy processing. */
-            if(plugin_ptr->processing)
-                continue;
+	    /* Skip plug-ins that are busy processing */
+	    if(plugin_ptr->processing)
+		continue;
 
-            /* Does not support export? */
-            if(plugin_ptr->export == NULL)
-                continue;
+	    /* Does not support export? */
+	    if(plugin_ptr->export == NULL)
+		continue;
 
-            /* Plug-in is loaded/enabled, check if it supports
-             * exporting.
-             */
-            for(n = 0; n < plugin_ptr->total_export_ftypes; n++)
-            {
-                FileBrowserTypeListNew(
-                    &ftype, &total_ftypes,
-                    plugin_ptr->export_ftype_ext[n],
-                    plugin_ptr->export_ftype_name[n]
-                );
-            }
-        }
+	    /* Plug-in is loaded/enabled, check if it supports
+	     * exporting.
+	     */
+	    for(n = 0; n < plugin_ptr->total_export_ftypes; n++)
+	    {
+		FileBrowserTypeListNew(
+		    &ftype, &total_ftypes,
+		    plugin_ptr->export_ftype_ext[n],
+		    plugin_ptr->export_ftype_name[n]
+		);
+	    }
+	}
 
-        /* Got no additional file types? */
-        if(total_ftypes <= 1)
-        {
-            /* This means we have no plug-ins with stated exporting
-             * support.
-             */
-        }
+	/* Got no additional file types? */
+	if(total_ftypes <= 1)
+	{
+	    /* This means we have no plug-ins with stated exporting
+	     * support.
+	     */
+	}
 
-        /* Query user for file. */
-        filename = NULL;
-        extension = NULL;
+	/* Query user for file */
+	filename = NULL;
+	extension = NULL;
 
 	FileBrowserSetTransientFor(editor->toplevel);
-        status = FileBrowserGetResponse(
-            "Export Model Data", "Export", "Cancel",
-            dname.fb_last_models,		/* Path. */
-            ftype, total_ftypes,
-            &path_rtn, &path_total_rtns,
-            &ftype_rtn
-        );
+	status = FileBrowserGetResponse(
+	    "Export Model Data", "Export", "Cancel",
+	    dname.fb_last_models,		/* Path */
+	    ftype, total_ftypes,
+	    &path_rtn, &path_total_rtns,
+	    &ftype_rtn
+	);
 	FileBrowserSetTransientFor(NULL);
 
 	if(status)
-        {
-            if(path_total_rtns > 0)
-            {
-                const gchar *cstrptr = (const gchar *)path_rtn[
-                    path_total_rtns - 1
-                ];
-                filename = ((cstrptr == NULL) ? NULL : g_strdup(cstrptr));
-            }
-        }
+	{
+	    if(path_total_rtns > 0)
+	    {
+		const gchar *cstrptr = (const gchar *)path_rtn[
+		    path_total_rtns - 1
+		];
+		filename = ((cstrptr == NULL) ? NULL : g_strdup(cstrptr));
+	    }
+	}
 
-        /* Get extension if any. */
-        if(ftype_rtn != NULL)
-        {
-            if(ftype_rtn->ext != NULL)
-                extension = g_strdup(ftype_rtn->ext);
-        }
+	/* Get extension if any */
+	if(ftype_rtn != NULL)
+	{
+	    if(ftype_rtn->ext != NULL)
+		extension = g_strdup(ftype_rtn->ext);
+	}
 
-        /* Deallocate all file types. */
-        FileBrowserDeleteTypeList(ftype, total_ftypes);
-        ftype = NULL;
-        total_ftypes = 0;
+	/* Delete file types list */
+	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	ftype = NULL;
+	total_ftypes = 0;
+
+        /* Reset due to possible file related change */
+        FileBrowserReset();
 
 
-        /* If filename or extension is NULL then that implies that user
-         * canceled.
-         */
-        if((filename == NULL) || (extension == NULL))
-        {
-            g_free(filename);
-            g_free(extension);
-            return(-4);
-        }
+	/* If filename or extension is NULL then that implies that user
+	 * canceled
+	 */
+	if((filename == NULL) || (extension == NULL))
+	{
+	    g_free(filename);
+	    g_free(extension);
+	    return(-4);
+	}
 
-        /* Handle by extension, plugin_ptr will be updated to point
-         * to the correct plug-in that supports the format or NULL
-         * on failure.
-         */
+	/* Handle by extension, plugin_ptr will be updated to point
+	 * to the correct plug-in that supports the format or NULL
+	 * on failure.
+	 */
 	plugin_ptr = NULL;
 	for(i = 0; i < core_ptr->total_plugins; i++)
 	{
@@ -525,7 +528,7 @@ gint EditorDoExport(ma_editor_struct *editor)
 	    if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
 		continue;
 
-	    /* Skip plug-ins that are busy processing. */
+	    /* Skip plug-ins that are busy processing */
 	    if(plugin_ptr->processing)
 		continue;
 
@@ -554,81 +557,81 @@ gint EditorDoExport(ma_editor_struct *editor)
 	    }
 	    else
 	    {
-		/* Got matching extension. */
+		/* Got matching extension */
 		break;
 	    }
 	}
 	if(i >= core_ptr->total_plugins)
 	    plugin_ptr = NULL;
 
-        /* Found plug-in that supports this extension type, supports
-         * exporting, and is currently not processing?
-         */  
-        if((plugin_ptr == NULL) ? 0 :
-            (plugin_ptr->export != NULL) && 
-            !plugin_ptr->processing
-        )
-        {
-            vpi_op_export_struct v;
+	/* Found plug-in that supports this extension type, supports
+	 * exporting, and is currently not processing?
+	 */  
+	if((plugin_ptr == NULL) ? 0 :
+	    (plugin_ptr->export != NULL) && 
+	    !plugin_ptr->processing
+	)
+	{
+	    vpi_op_export_struct v;
 
 
-            /* Set up export operation value structure. */
-            v.flags = (VPI_OP_EXPORT_EDITOR_ID |
-                VPI_OP_EXPORT_FILENAME | VPI_OP_EXPORT_HEADER |
-                VPI_OP_EXPORT_MODELS
-            );
-            for(i = 0; i < core_ptr->total_editors; i++)
-            {
-                if(core_ptr->editor[i] == editor)
-                    break;
-            }
-            v.editor_id = i;
-            v.filename = g_strdup(filename);
-            v.mh_item = editor->mh_item;
-            v.total_mh_items = editor->total_mh_items;
-            v.model = editor->model;
-            v.total_models = editor->total_models;
+	    /* Set up export operation value structure */
+	    v.flags = (VPI_OP_EXPORT_EDITOR_ID |
+		VPI_OP_EXPORT_FILENAME | VPI_OP_EXPORT_HEADER |
+		VPI_OP_EXPORT_MODELS
+	    );
+	    for(i = 0; i < core_ptr->total_editors; i++)
+	    {
+		if(core_ptr->editor[i] == editor)
+		    break;
+	    }
+	    v.editor_id = i;
+	    v.filename = g_strdup(filename);
+	    v.mh_item = editor->mh_item;
+	    v.total_mh_items = editor->total_mh_items;
+	    v.model = editor->model;
+	    v.total_models = editor->total_models;
 
-            /* Mark editor and plug-in as processing. */
-            EditorSetBusy(editor);
+	    /* Mark editor and plug-in as processing */
+	    EditorSetBusy(editor);
 /*	    editor->processing = TRUE; */
-            plugin_ptr->processing = 1;
+	    plugin_ptr->processing = 1;
 
-            /* Call plug-in's export function. */
-            status = plugin_ptr->export(
-                (vpi_id *)plugin_ptr,
-                &v,
-                plugin_ptr->export_data
-            );
+	    /* Call plug-in's export function */
+	    status = plugin_ptr->export(
+		(vpi_id *)plugin_ptr,
+		&v,
+		plugin_ptr->export_data
+	    );
 
-            /* Mark editor and plug-in as done processing. */
-            plugin_ptr->processing = 0;
-            EditorSetReady(editor);
+	    /* Mark editor and plug-in as done processing */
+	    plugin_ptr->processing = 0;
+	    EditorSetReady(editor);
 /*	    editor->processing = FALSE; */
 
-            /* Deallocate export values structure members. */
-            g_free(v.filename);
+	    /* Deallocate export values structure members */
+	    g_free(v.filename);
 
-	    /* Do not modify has changes mark on editor. */
+	    /* Do not modify has changes mark on editor */
 
-            /* Update editor and redraw. */
-            EditorUpdateMenus(editor);
-            EditorUpdateAllViewMenus(editor);
-            EditorRedrawAllViews(editor);
+	    /* Update editor and redraw */
+	    EditorUpdateMenus(editor);
+	    EditorUpdateAllViewMenus(editor);
+	    EditorRedrawAllViews(editor);
 
-            VMAStatusBarMessage(editor->sb, "Export done");
-        }
-        else
-        {       
-            /* No plug-in available that supports this format. */
-            gint len = (80 * 8) + strlen(filename);
-            gchar *buf;
+	    VMAStatusBarMessage(editor->sb, "Export done");
+	}
+	else
+	{       
+	    /* No plug-in available that supports this format */
+	    gint len = (80 * 8) + strlen(filename);
+	    gchar *buf;
 
-            VMAStatusBarMessage(editor->sb, "Export failed");
+	    VMAStatusBarMessage(editor->sb, "Export failed");
 
-            buf = (gchar *)g_malloc((len + 1) * sizeof(gchar));
-            if(buf != NULL)
-                sprintf(buf,
+	    buf = (gchar *)g_malloc((len + 1) * sizeof(gchar));
+	    if(buf != NULL)
+		sprintf(buf,
 "There are no installed or enabled plug-ins that\n\
 supports the format of the file:\n\
 \n\
@@ -637,47 +640,47 @@ supports the format of the file:\n\
 You may want to try selecting an exact file format\n\
 instead of automatic detect or try to obtain/install\n\
 a plug-in that supports this file's format.",
-                    filename
-                );
+		    filename
+		);
 
-            CDialogSetTransientFor(editor->toplevel);
-            CDialogGetResponse(
+	    CDialogSetTransientFor(editor->toplevel);
+	    CDialogGetResponse(
 "Export failed!",
-                buf,
+		buf,
 "Exporting of different file formats are handled by\n\
 plug-ins. You need to enable or obtain/install\n\
 a plug-in that supports the format in question.",
-                CDIALOG_ICON_ERROR,
-                CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
-                CDIALOG_BTNFLAG_OK
-            );
-            CDialogSetTransientFor(NULL);
+		CDIALOG_ICON_ERROR,
+		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    CDialogSetTransientFor(NULL);
 
-            g_free(buf);
-            buf = NULL;
-        }
+	    g_free(buf);
+	    buf = NULL;
+	}
 
-        /* Record last path. */
-        VMARecordFBPath(
-            filename,
-            dname.fb_last_models,
-            1
-        );
+	/* Record last path */
+	VMARecordFBPath(
+	    filename,
+	    dname.fb_last_models,
+	    1
+	);
 
-        /* Update last export file type extension. */
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_LAST_EXT_EXPORT,
-            extension, TRUE
-        );
-        /* Update last exported file. */
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_LAST_FILE_EXPORT,
-            filename, TRUE
-        );
+	/* Update last export file type extension */
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_LAST_EXT_EXPORT,
+	    extension, TRUE
+	);
+	/* Update last exported file */
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_LAST_FILE_EXPORT,
+	    filename, TRUE
+	);
 
-        /* Deallocate file name and extension. */
-        g_free(filename);
-        g_free(extension);
+	/* Deallocate file name and extension */
+	g_free(filename);
+	g_free(extension);
 
-        return(0);
+	return(0);
 }
