@@ -152,19 +152,19 @@ static void VMACreateFileTypes(vma_ftype_struct *buf)
 	DO_ADD_STRING_LIST
 
 	string_list = string_list_save_model;
-        list = &buf->save_model;
-        list_total = &buf->save_model_total;
+	list = &buf->save_model;
+	list_total = &buf->save_model_total;
 	DO_ADD_STRING_LIST
 
 	string_list = string_list_load_texture;
-        list = &buf->load_texture;
-        list_total = &buf->load_texture_total;
+	list = &buf->load_texture;
+	list_total = &buf->load_texture_total;
 	DO_ADD_STRING_LIST
 
-        string_list = string_list_view_background_image;
-        list = &buf->view_background_image;
-        list_total = &buf->view_background_image_total;
-        DO_ADD_STRING_LIST
+	string_list = string_list_view_background_image;
+	list = &buf->view_background_image;
+	list_total = &buf->view_background_image_total;
+	DO_ADD_STRING_LIST
 
 
 #undef DO_ADD_STRING_LIST
@@ -175,8 +175,8 @@ static void VMACreateFileTypes(vma_ftype_struct *buf)
  */
 static void VMADestroyFileTypes(vma_ftype_struct *buf)
 {
-        fb_type_struct ***list;
-        gint *list_total;
+	fb_type_struct ***list;
+	gint *list_total;
 
 
 	if(buf == NULL)
@@ -189,21 +189,21 @@ static void VMADestroyFileTypes(vma_ftype_struct *buf)
  (*list_total) = 0; \
 }
 
-        list = &buf->load_model;
-        list_total = &buf->load_model_total;
+	list = &buf->load_model;
+	list_total = &buf->load_model_total;
 	DO_REMOVE_ALL
 
-        list = &buf->save_model;
-        list_total = &buf->save_model_total;
-        DO_REMOVE_ALL
+	list = &buf->save_model;
+	list_total = &buf->save_model_total;
+	DO_REMOVE_ALL
 
-        list = &buf->load_texture;
-        list_total = &buf->load_texture_total;
-        DO_REMOVE_ALL
+	list = &buf->load_texture;
+	list_total = &buf->load_texture_total;
+	DO_REMOVE_ALL
 
 	list = &buf->view_background_image;
-        list_total = &buf->view_background_image_total;
-        DO_REMOVE_ALL
+	list_total = &buf->view_background_image_total;
+	DO_REMOVE_ALL
 
 #undef DO_REMOVE_ALL
 }
@@ -242,10 +242,7 @@ int main(int argc, char *argv[])
 	core_ptr = (vma_core_struct *)g_malloc0(sizeof(vma_core_struct));
 	if(core_ptr == NULL)
 	{
-	    fprintf(
-		stderr,
-		"Memory allocation error.\n"
-	    );
+	    g_printerr("Memory allocation error.\n");
 	    return(3);
 	}
 
@@ -280,40 +277,40 @@ int main(int argc, char *argv[])
 	strptr = dname.data_global;
 	cstrptr = (const gchar *)VMADefaultDataGlobalDir();
 	strncpy(strptr, cstrptr, PATH_MAX);
-        strptr[PATH_MAX - 1] = '\0';
+	strptr[PATH_MAX - 1] = '\0';
 
 	/* User's home directory. */
 	strptr = dname.home;
 	cstrptr = (const gchar *)getenv("HOME");
 	strncpy(strptr, (cstrptr == NULL) ? "/" : cstrptr, PATH_MAX);
-        strptr[PATH_MAX - 1] = '\0';
+	strptr[PATH_MAX - 1] = '\0';
 
 	/* Local program data directory. */
-        strptr = dname.data_local;
-        cstrptr = (const gchar *)PrefixPaths(dname.home, VMA_DEF_DATA_LOCAL_DIR);
-        strncpy(strptr, (cstrptr == NULL) ? "/" : cstrptr, PATH_MAX);
+	strptr = dname.data_local;
+	cstrptr = (const gchar *)PrefixPaths(dname.home, VMA_DEF_DATA_LOCAL_DIR);
+	strncpy(strptr, (cstrptr == NULL) ? "/" : cstrptr, PATH_MAX);
 	strptr[PATH_MAX - 1] = '\0';
 
 	/* Preferences file. */
 	strptr = fname.preferences;
 	cstrptr = (const gchar *)PrefixPaths(dname.data_local, VMA_DEF_PREFERENCES_FILE);
 	strncpy(strptr, (cstrptr == NULL) ? "/" : cstrptr, PATH_MAX);
-        strptr[PATH_MAX + NAME_MAX - 1] = '\0';
+	strptr[PATH_MAX + NAME_MAX - 1] = '\0';
 
 	/* Reset last models dir to value of home dir. */
-        strptr = dname.fb_last_models;
-        strncpy(strptr, dname.home, PATH_MAX);
-        strptr[PATH_MAX - 1] = '\0';
+	strptr = dname.fb_last_models;
+	strncpy(strptr, dname.home, PATH_MAX);
+	strptr[PATH_MAX - 1] = '\0';
 
 	/* Reset last textures dir to value of home dir. */
-        strptr = dname.fb_last_textures;
-        strncpy(strptr, dname.home, PATH_MAX);
-        strptr[PATH_MAX - 1] = '\0';
+	strptr = dname.fb_last_textures;
+	strncpy(strptr, dname.home, PATH_MAX);
+	strptr[PATH_MAX - 1] = '\0';
 
 	/* Reset last view background image dir to value of home dir. */
 	strptr = dname.fb_last_view_background_image;
 	strncpy(strptr, dname.home, PATH_MAX);
-        strptr[PATH_MAX - 1] = '\0';
+	strptr[PATH_MAX - 1] = '\0';
 
 	/* Reset scratchpad file. */
 	strptr = fname.scratchpad;
@@ -325,19 +322,19 @@ int main(int argc, char *argv[])
 	    (cstrptr == NULL) ? VMA_DEF_SCRATCHPAD_FILE : cstrptr,
 	    PATH_MAX + NAME_MAX
 	);
-        strptr[PATH_MAX + NAME_MAX - 1] = '\0';
+	strptr[PATH_MAX + NAME_MAX - 1] = '\0';
 
-        /* Reset plugins file. */
-        strptr = fname.plugins;
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_local, VMA_DEF_PLUGINS_FILE
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? VMA_DEF_PLUGINS_FILE : cstrptr,
-            PATH_MAX + NAME_MAX
-        );
-        strptr[PATH_MAX + NAME_MAX - 1] = '\0';
+	/* Reset plugins file. */
+	strptr = fname.plugins;
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_local, VMA_DEF_PLUGINS_FILE
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? VMA_DEF_PLUGINS_FILE : cstrptr,
+	    PATH_MAX + NAME_MAX
+	);
+	strptr[PATH_MAX + NAME_MAX - 1] = '\0';
 
 	/* Reset local and global preset models directories. */
 	strptr = dname.preset_models_global;
@@ -351,62 +348,62 @@ int main(int argc, char *argv[])
 	);
 	strptr[PATH_MAX - 1] = '\0';
 
-        strptr = dname.preset_models_local;
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_local, VMA_DEF_PRESET_MODELS_DIR 
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? dname.data_local : cstrptr,
-            PATH_MAX
-        );
-        strptr[PATH_MAX - 1] = '\0';
+	strptr = dname.preset_models_local;
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_local, VMA_DEF_PRESET_MODELS_DIR 
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? dname.data_local : cstrptr,
+	    PATH_MAX
+	);
+	strptr[PATH_MAX - 1] = '\0';
 
-        /* Reset local and global preset primitives directories. */
-        strptr = dname.preset_primitives_global;
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_global, VMA_DEF_PRESET_PRIMITIVES_DIR 
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? dname.data_global : cstrptr,
-            PATH_MAX
-        );
-        strptr[PATH_MAX - 1] = '\0';
+	/* Reset local and global preset primitives directories. */
+	strptr = dname.preset_primitives_global;
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_global, VMA_DEF_PRESET_PRIMITIVES_DIR 
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? dname.data_global : cstrptr,
+	    PATH_MAX
+	);
+	strptr[PATH_MAX - 1] = '\0';
 
-        strptr = dname.preset_primitives_local; 
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_local, VMA_DEF_PRESET_PRIMITIVES_DIR
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? dname.data_local : cstrptr,
-            PATH_MAX
-        );
-        strptr[PATH_MAX - 1] = '\0';
+	strptr = dname.preset_primitives_local; 
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_local, VMA_DEF_PRESET_PRIMITIVES_DIR
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? dname.data_local : cstrptr,
+	    PATH_MAX
+	);
+	strptr[PATH_MAX - 1] = '\0';
 
-        /* Plug-ins directories. */
-        strptr = dname.plugins_global;
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_global, VMA_DEF_PLUGINS_DIR
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? dname.data_global : cstrptr,
-            PATH_MAX
-        );
-        strptr[PATH_MAX - 1] = '\0';
+	/* Plug-ins directories. */
+	strptr = dname.plugins_global;
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_global, VMA_DEF_PLUGINS_DIR
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? dname.data_global : cstrptr,
+	    PATH_MAX
+	);
+	strptr[PATH_MAX - 1] = '\0';
 
-        strptr = dname.plugins_local;
-        cstrptr = (const gchar *)PrefixPaths(
-            dname.data_local, VMA_DEF_PLUGINS_DIR
-        );
-        strncpy(
-            strptr,
-            (cstrptr == NULL) ? dname.data_local : cstrptr,
-            PATH_MAX
-        );
-        strptr[PATH_MAX - 1] = '\0';
+	strptr = dname.plugins_local;
+	cstrptr = (const gchar *)PrefixPaths(
+	    dname.data_local, VMA_DEF_PLUGINS_DIR
+	);
+	strncpy(
+	    strptr,
+	    (cstrptr == NULL) ? dname.data_local : cstrptr,
+	    PATH_MAX
+	);
+	strptr[PATH_MAX - 1] = '\0';
 
 
 	/* Reset global initialized GTK marker. */
@@ -428,10 +425,10 @@ int main(int argc, char *argv[])
 	    /* Help. */
 	    if(strcasepfx(parm, "--h") ||
 	       strcasepfx(parm, "-h") ||
-               strcasepfx(parm, "--?") ||
-               strcasepfx(parm, "-?") ||
-               strcasepfx(parm, "/?") ||
-               strcasepfx(parm, "?")
+	       strcasepfx(parm, "--?") ||
+	       strcasepfx(parm, "-?") ||
+	       strcasepfx(parm, "/?") ||
+	       strcasepfx(parm, "?")
 	    )
 	    {
 		printf(
@@ -443,38 +440,38 @@ int main(int argc, char *argv[])
 		g_free(core_ptr);
 		return(0);
 	    }
-            /* Version. */
-            else if(strcasepfx(parm, "--version") ||
-                    strcasepfx(parm, "-version")
-            )
-            {
+	    /* Version. */
+	    else if(strcasepfx(parm, "--version") ||
+		    strcasepfx(parm, "-version")
+	    )
+	    {
 		const gchar *copyright_str = MsgListMatchCaseMessage(
 		    msglist_std, VMA_MSGNAME_STD_COPYRIGHT
 		);
 		printf("%s %s\n%s\n",
 		    PROG_NAME, PROG_VERSION, copyright_str
 		);
-                g_free(core_ptr);
-                return(0);
-            }
+		g_free(core_ptr);
+		return(0);
+	    }
 
 	    /* Preferences file. */
 	    else if(!strcasecmp(parm, "--rcfile") ||
-                    !strcasecmp(parm, "-rcfile") ||
-                    !strcasecmp(parm, "--configuration_file") ||
-                    !strcasecmp(parm, "-configuration_file") ||
-                    !strcasecmp(parm, "--configurationfile") ||
-                    !strcasecmp(parm, "-configurationfile") ||
-                    !strcasecmp(parm, "--config_file") ||
-                    !strcasecmp(parm, "-config_file") ||
-                    !strcasecmp(parm, "--configfile") ||
-                    !strcasecmp(parm, "-configfile") ||
-                    !strcasecmp(parm, "--configuration") ||
-                    !strcasecmp(parm, "-configuration") ||
-                    !strcasecmp(parm, "--config") ||
-                    !strcasecmp(parm, "-config") ||
-                    !strcasecmp(parm, "--f") ||
-                    !strcasecmp(parm, "-f")
+		    !strcasecmp(parm, "-rcfile") ||
+		    !strcasecmp(parm, "--configuration_file") ||
+		    !strcasecmp(parm, "-configuration_file") ||
+		    !strcasecmp(parm, "--configurationfile") ||
+		    !strcasecmp(parm, "-configurationfile") ||
+		    !strcasecmp(parm, "--config_file") ||
+		    !strcasecmp(parm, "-config_file") ||
+		    !strcasecmp(parm, "--configfile") ||
+		    !strcasecmp(parm, "-configfile") ||
+		    !strcasecmp(parm, "--configuration") ||
+		    !strcasecmp(parm, "-configuration") ||
+		    !strcasecmp(parm, "--config") ||
+		    !strcasecmp(parm, "-config") ||
+		    !strcasecmp(parm, "--f") ||
+		    !strcasecmp(parm, "-f")
 	    )
 	    {
 		i++;
@@ -502,10 +499,10 @@ int main(int argc, char *argv[])
 			}
 			else
 			{
-                            strncpy(
-                                fname.preferences, strptr,
-                                PATH_MAX + NAME_MAX
-                            );
+			    strncpy(
+				fname.preferences, strptr,
+				PATH_MAX + NAME_MAX
+			    );
 			}
 		        fname.preferences[PATH_MAX + NAME_MAX - 1] = '\0';
 
@@ -515,13 +512,13 @@ int main(int argc, char *argv[])
 
 		    /* Check if new specified preferences file exists. */
 		    if(stat(fname.preferences, &stat_buf))
-                    {
+		    {
 /* Let loading of preferences determine this
-			fprintf(stderr,
+			g_printerr(
 			    "%s: No such file.\n",
 			    fname.preferences
 			);
-                        g_free(core_ptr);
+			g_free(core_ptr);
 			return(1);
  */
 		    }
@@ -529,50 +526,51 @@ int main(int argc, char *argv[])
 		    {
 			if(!S_ISREG(stat_buf.st_mode))
 			{
-                            fprintf(stderr,
-                                "%s: Not a file.\n",
-                                fname.preferences
-                            );
-                            g_free(core_ptr);
-                            return(1);
+			    g_printerr(
+				"%s: Not a file.\n",
+				fname.preferences
+			    );
+			    g_free(core_ptr);
+			    return(1);
 			}
 
 		    }
 		}
 		else
 		{
-		    fprintf(stderr, "%s: Requires argument.\n",
+		    g_printerr(
+			"%s: Requires argument.\n",
 			argv[i - 1]
 		    );
-                    g_free(core_ptr);
+		    g_free(core_ptr);
 		    return(1);
 		}
 	    }
 	    /* Disable plug-ins on startup. */
 	    else if(strcasepfx(parm, "--disable_plugins") ||
-                    strcasepfx(parm, "-disable_plugins") ||
-                    strcasepfx(parm, "--disable-plugins") ||
-                    strcasepfx(parm, "-disable-plugins") ||
-                    strcasepfx(parm, "--disableplugins") ||
-                    strcasepfx(parm, "-disableplugins")
+		    strcasepfx(parm, "-disable_plugins") ||
+		    strcasepfx(parm, "--disable-plugins") ||
+		    strcasepfx(parm, "-disable-plugins") ||
+		    strcasepfx(parm, "--disableplugins") ||
+		    strcasepfx(parm, "-disableplugins")
 	    )
 	    {
 		load_plugins_on_startup = FALSE;
 	    }
 	    /* Do not show splash on startup. */
 	    else if(strcasepfx(parm, "--no_splash") ||
-                    strcasepfx(parm, "-no_splash") ||
-                    strcasepfx(parm, "--no-splash") ||
-                    strcasepfx(parm, "-no-splash") ||
-                    strcasepfx(parm, "--nosplash") ||
-                    strcasepfx(parm, "-nosplash")
+		    strcasepfx(parm, "-no_splash") ||
+		    strcasepfx(parm, "--no-splash") ||
+		    strcasepfx(parm, "-no-splash") ||
+		    strcasepfx(parm, "--nosplash") ||
+		    strcasepfx(parm, "-nosplash")
 	    )
-            {
+	    {
 		show_splash_on_startup = FALSE;
 	    }
 	    /* Some other unsupported option? */
 	    else if(strpfx(parm, "+") ||
-                    strpfx(parm, "-")
+		    strpfx(parm, "-")
 	    )
 	    {
 
@@ -587,12 +585,12 @@ int main(int argc, char *argv[])
 	/* Set signals to watch for. */
 #ifndef MEMWATCH
 	signal(SIGINT, VMASignalCB);
-        signal(SIGTERM, VMASignalCB);
-        signal(SIGKILL, VMASignalCB);
-        signal(SIGSEGV, VMASignalCB);
-        signal(SIGSTOP, VMASignalCB);
-        signal(SIGCONT, VMASignalCB);
-        signal(SIGPIPE, VMASignalCB);
+	signal(SIGTERM, VMASignalCB);
+	signal(SIGKILL, VMASignalCB);
+	signal(SIGSEGV, VMASignalCB);
+	signal(SIGSTOP, VMASignalCB);
+	signal(SIGCONT, VMASignalCB);
+	signal(SIGPIPE, VMASignalCB);
 #endif
 
 	/* Check if global configuration options list is declared
@@ -601,8 +599,7 @@ int main(int argc, char *argv[])
 	status = sizeof(option) / sizeof(vma_cfg_item_struct *);
 	if((status % 3) != 0)
 	{
-	    fprintf(
-		stderr,
+	    g_printerr(
 "Internal error: vma_cfg_item_struct option[] is not aligned with 3 pointers.\n"
 	    );
 	}
@@ -628,22 +625,22 @@ int main(int argc, char *argv[])
 		switch(status)
 		{
 		  case -4:	/* User aborted. */
-                    g_free(core_ptr);
+		    g_free(core_ptr);
 		    return(4);
 		    break;
 
 		  case -3:	/* Systems error. */
-                    g_free(core_ptr);
+		    g_free(core_ptr);
 		    return(3);
 		    break;
 
 		  case -2:
-                    g_free(core_ptr);
+		    g_free(core_ptr);
 		    return(2);
 		    break;
 
 		  default:	/* All else assume -1, general error. */
-                    g_free(core_ptr);
+		    g_free(core_ptr);
 		    return(1);
 		    break;
 		}
@@ -667,9 +664,9 @@ int main(int argc, char *argv[])
 	    old_version_major = VMACFGItemListGetValueI(
 		option, VMA_CFG_PARM_VERSION_MAJOR
 	    );
-            old_version_minor = VMACFGItemListGetValueI(
-                option, VMA_CFG_PARM_VERSION_MINOR
-            );
+	    old_version_minor = VMACFGItemListGetValueI(
+		option, VMA_CFG_PARM_VERSION_MINOR
+	    );
 	    if(old_version_major < PROG_VERSION_MAJOR)
 		need_upgrade = TRUE;
 	    else if(old_version_minor < PROG_VERSION_MINOR)
@@ -677,32 +674,32 @@ int main(int argc, char *argv[])
 
 	    if(need_upgrade)
 	    {
-                status = VMADoInstallUpgrade(
-                    &argc, &argv,
-                    fname.preferences, option
-                );
-                if(status)
-                {
-                    /* Upgrade failed, check reason. */
+		status = VMADoInstallUpgrade(
+		    &argc, &argv,
+		    fname.preferences, option
+		);
+		if(status)
+		{
+		    /* Upgrade failed, check reason. */
 		    switch(status)
 		    {
 		      case -4:	/* User aborted. */
-                        g_free(core_ptr);
+			g_free(core_ptr);
 			return(4);
 			break;
 
 		      case -3:	/* Systems error. */
-                        g_free(core_ptr);
+			g_free(core_ptr);
 			return(3);
 			break;
 
 		      case -2:
-                        g_free(core_ptr);
+			g_free(core_ptr);
 			return(2);
 			break;
 
 		      default:	/* All else assume -1, general error. */
-                        g_free(core_ptr);
+			g_free(core_ptr);
 			return(1);
 			break;
 		    }
@@ -726,121 +723,121 @@ int main(int argc, char *argv[])
 	VMACFGItemListMatchSetValue(
 	    option, VMA_CFG_PARM_VERSION_MAJOR, (void *)&val_32, FALSE
 	);
-        /* Version minor. */
-        val_32 = PROG_VERSION_MINOR;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_VERSION_MINOR, (void *)&val_32, FALSE
-        );
+	/* Version minor. */
+	val_32 = PROG_VERSION_MINOR;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_VERSION_MINOR, (void *)&val_32, FALSE
+	);
 
-        /* Get local and global data directories. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_LOCAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.data_local; 
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
+	/* Get local and global data directories. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_LOCAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.data_local; 
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
 	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_GLOBAL);
 	if(strptr != NULL)
 	{
-            strptr2 = dname.data_global;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        /* Get local and global preset models directories. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_MODELS_LOCAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.preset_models_local;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_MODELS_GLOBAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.preset_models_global;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        /* Get local and global preset primitives directories. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_LOCAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.preset_primitives_local;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_GLOBAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.preset_primitives_global;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        /* Get local and global plug-ins directories. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PLUGINS_LOCAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.plugins_local;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PLUGINS_GLOBAL);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.plugins_global;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
-        /* Get tempory files directory. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_TMP);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.tmp;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';  
-        }
+	    strptr2 = dname.data_global;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	/* Get local and global preset models directories. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_MODELS_LOCAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.preset_models_local;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_MODELS_GLOBAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.preset_models_global;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	/* Get local and global preset primitives directories. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_LOCAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.preset_primitives_local;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_GLOBAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.preset_primitives_global;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	/* Get local and global plug-ins directories. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PLUGINS_LOCAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.plugins_local;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_PLUGINS_GLOBAL);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.plugins_global;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
+	/* Get tempory files directory. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_DIR_TMP);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.tmp;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';  
+	}
 	/* Get last models directory. */
 	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_LAST_DIR_MODELS);
-        if(strptr != NULL)
+	if(strptr != NULL)
 	{
 	    strptr2 = dname.fb_last_models;
 	    strncpy(strptr2, strptr, PATH_MAX);
 	    strptr2[PATH_MAX - 1] = '\0';
 	}
 	/* Get last textures directory. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_LAST_DIR_TEXTURES);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.fb_last_textures;
-            strncpy(strptr2, strptr, PATH_MAX);
-            strptr2[PATH_MAX - 1] = '\0';
-        }
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_LAST_DIR_TEXTURES);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.fb_last_textures;
+	    strncpy(strptr2, strptr, PATH_MAX);
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
 	/* Get last view background image directory. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_LAST_DIR_VIEW_BACKGROUND_IMAGE);
-        if(strptr != NULL)
-        {
-            strptr2 = dname.fb_last_view_background_image;
-            strncpy(strptr2, strptr, PATH_MAX);   
-            strptr2[PATH_MAX - 1] = '\0';
-        }
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_LAST_DIR_VIEW_BACKGROUND_IMAGE);
+	if(strptr != NULL)
+	{
+	    strptr2 = dname.fb_last_view_background_image;
+	    strncpy(strptr2, strptr, PATH_MAX);   
+	    strptr2[PATH_MAX - 1] = '\0';
+	}
 
 	/* Scratch pad file. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_FILE_SCRATCHPAD);
-        if(strptr != NULL)
-        {
-            strptr2 = fname.scratchpad;
-            strncpy(strptr2, strptr, PATH_MAX + NAME_MAX);
-            strptr2[PATH_MAX + NAME_MAX - 1] = '\0';
-        }
-        /* Plugins file. */
-        strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_FILE_PLUGINS);
-        if(strptr != NULL)
-        {
-            strptr2 = fname.plugins;
-            strncpy(strptr2, strptr, PATH_MAX + NAME_MAX);
-            strptr2[PATH_MAX + NAME_MAX - 1] = '\0';
-        }
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_FILE_SCRATCHPAD);
+	if(strptr != NULL)
+	{
+	    strptr2 = fname.scratchpad;
+	    strncpy(strptr2, strptr, PATH_MAX + NAME_MAX);
+	    strptr2[PATH_MAX + NAME_MAX - 1] = '\0';
+	}
+	/* Plugins file. */
+	strptr = VMACFGItemListGetValueS(option, VMA_CFG_PARM_FILE_PLUGINS);
+	if(strptr != NULL)
+	{
+	    strptr2 = fname.plugins;
+	    strncpy(strptr2, strptr, PATH_MAX + NAME_MAX);
+	    strptr2[PATH_MAX + NAME_MAX - 1] = '\0';
+	}
 
 
 
@@ -851,13 +848,10 @@ int main(int argc, char *argv[])
 	/* Initialize GTK+ as needed. */
 	if(!initialized_gtk)
 	{
-            if(!gtk_init_check(&argc, &argv))
+	    if(!gtk_init_check(&argc, &argv))
 	    {
-                fprintf(
-                    stderr,
- "This program requires X.\n"
-                );
-                g_free(core_ptr);
+		g_printerr("Unable to initialize GTK.\n");
+		g_free(core_ptr);
 		return(1);
 	    }
 	    initialized_gtk = TRUE;
@@ -872,12 +866,12 @@ int main(int argc, char *argv[])
 #endif
 
 	/* Check if OpenGL available. */
-        if(gdk_gl_query() == FALSE)
-        {
-            fprintf(stderr, "OpenGL not available.\n");
-            g_free(core_ptr);
-            return(1);
-        }
+	if(gdk_gl_query() == FALSE)
+	{
+	    g_printerr("OpenGL not available.\n");
+	    g_free(core_ptr);
+	    return(1);
+	}
 
 	/* Create splash window? */
 	if(show_splash_on_startup && (core_ptr->splash_win == NULL))
@@ -903,13 +897,13 @@ int main(int argc, char *argv[])
 	    NULL,
 	    TRUE
 	);
-        SplashUpdate(
-            core_ptr->splash_win,
-            1,			/* Progress bar number. */
-            0.0,
-            NULL,
-            TRUE
-        );
+	SplashUpdate(
+	    core_ptr->splash_win,
+	    1,			/* Progress bar number. */
+	    0.0,
+	    NULL,
+	    TRUE
+	);
 
 
 	/* Enable/disable tooltips. */
@@ -918,8 +912,8 @@ int main(int argc, char *argv[])
 	else
 	    GUISetGlobalTipsState(FALSE);
 
-        /* Load GTK+ styles list. */
-        VMAStylesListCreate(&styles_list);
+	/* Load GTK+ styles list. */
+	VMAStylesListCreate(&styles_list);
 
 	/* Load global pixmaps. */
 	VMAPixmapsListLoad(core_ptr, &vma_pixmaps_list, core_ptr->splash_win);
@@ -934,7 +928,7 @@ int main(int argc, char *argv[])
 	ClipboardBrowserInit();
 
 	/* Color selection dialog. */
-        CSDInit();
+	CSDInit();
 
 	/* Font selection dialog. */
 	FSDInit();
@@ -1022,11 +1016,11 @@ int main(int argc, char *argv[])
 		    TRUE
 		) == SPLASH_ABORT)
 		    break;
-            }
+	    }
 	}
 
 
-        /* Create first editor. */
+	/* Create first editor. */
 	SplashUpdate(
 	    core_ptr->splash_win,
 	    0, 0.0,
@@ -1034,26 +1028,26 @@ int main(int argc, char *argv[])
 	    TRUE
 	);
 	VMANewEditor(core_ptr);
-        SplashUpdate(
-            core_ptr->splash_win,
-            0, 1.0,
-            "Creating editor...",
-            TRUE
-        );
+	SplashUpdate(
+	    core_ptr->splash_win,
+	    0, 1.0,
+	    "Creating editor...",
+	    TRUE
+	);
 
 
-        /* Destroy splash window, we don't need it anymore. Note that
+	/* Destroy splash window, we don't need it anymore. Note that
 	 * the splash window should be destroyed just before its possible
 	 * for user input, otherwise we have reenterent issues which
 	 * although may not be serious- we'ed rather not worry about it.
 	 */
-        SplashDelete(core_ptr->splash_win);
-        core_ptr->splash_win = NULL;
+	SplashDelete(core_ptr->splash_win);
+	core_ptr->splash_win = NULL;
 
 
 	/* Create tip of day window? */
 	if(VMACFGItemListGetValueI(option, VMA_CFG_PARM_SHOW_TIPOFDAY))
-        {
+	{
 	    static const gchar *tod_msglist[] = VMA_MSGLIST_TOD_MESSAGE_LIST;
 
 	    if(core_ptr->todwin == NULL)
@@ -1073,13 +1067,13 @@ int main(int argc, char *argv[])
 	}
 
 
-        /* Set GTK+ timeout callbacks. */
+	/* Set GTK+ timeout callbacks. */
 	/* Standard timeout callback. */
 	vma_manage_toid = gtk_timeout_add(
-            1000,		/* 1 second interval. */
-            (GtkFunction)VMATimeoutCB,
-            core_ptr
-        );
+	    1000,		/* 1 second interval. */
+	    (GtkFunction)VMATimeoutCB,
+	    core_ptr
+	);
 	/* Backup timeout callback. */
 	i = VMACFGItemListGetValueI(option, VMA_CFG_PARM_BACKUP_PERIODIC_INT);
 	if(i > 0)
@@ -1109,16 +1103,16 @@ int main(int argc, char *argv[])
 	);
 /*
 	core_ptr->plugin_manage_idleid = gtk_idle_add_priority(
-            G_PRIORITY_LOW,
-            (GtkFunction)VMAPluginManageTimeoutCB,
-            (gpointer)core_ptr
-        );
+	    G_PRIORITY_LOW,
+	    (GtkFunction)VMAPluginManageTimeoutCB,
+	    (gpointer)core_ptr
+	);
  */
 
 
 	/* Load filename at startup? */
 	if((filename != NULL) &&
-           (core_ptr->total_editors > 0)
+	   (core_ptr->total_editors > 0)
 	)
 	{
 	    ma_editor_struct *editor_ptr = core_ptr->editor[0];
@@ -1132,7 +1126,7 @@ int main(int argc, char *argv[])
 
 
 	/* Enter main GUI management loop. */
-        gtk_main();
+	gtk_main();
 
 
 	/* Begin updating certain preferences before saving them. */
@@ -1141,69 +1135,69 @@ int main(int argc, char *argv[])
 	VMACFGItemListMatchSetValue(
 	    option, VMA_CFG_PARM_DIR_LOCAL, strptr, TRUE
 	);
-        strptr = dname.data_global;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_GLOBAL, strptr, TRUE
-        );
+	strptr = dname.data_global;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_GLOBAL, strptr, TRUE
+	);
 	/* Local and global preset models directories. */
-        strptr = dname.preset_models_local;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PRESET_MODELS_LOCAL, strptr, TRUE
-        );
-        strptr = dname.preset_models_global;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PRESET_MODELS_GLOBAL, strptr, TRUE
-        );
-        /* Local and global preset primitives directories. */
-        strptr = dname.preset_primitives_local;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_LOCAL, strptr, TRUE
-        );
-        strptr = dname.preset_primitives_global;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_GLOBAL, strptr, TRUE
-        );
+	strptr = dname.preset_models_local;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PRESET_MODELS_LOCAL, strptr, TRUE
+	);
+	strptr = dname.preset_models_global;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PRESET_MODELS_GLOBAL, strptr, TRUE
+	);
+	/* Local and global preset primitives directories. */
+	strptr = dname.preset_primitives_local;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_LOCAL, strptr, TRUE
+	);
+	strptr = dname.preset_primitives_global;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PRESET_PRIMITIVES_GLOBAL, strptr, TRUE
+	);
 	/* Local and global plug-ins directories. */
-        strptr = dname.plugins_local;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PLUGINS_LOCAL, strptr, TRUE
-        );
-        strptr = dname.plugins_global;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_PLUGINS_GLOBAL, strptr, TRUE
-        );
+	strptr = dname.plugins_local;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PLUGINS_LOCAL, strptr, TRUE
+	);
+	strptr = dname.plugins_global;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_PLUGINS_GLOBAL, strptr, TRUE
+	);
 	/* Tempory directory. */
-        strptr = dname.tmp;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_DIR_TMP, strptr, TRUE
-        );
+	strptr = dname.tmp;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_DIR_TMP, strptr, TRUE
+	);
 	/* Last file paths. */
-        strptr = dname.fb_last_models;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_LAST_DIR_MODELS, strptr, TRUE
-        );
-        strptr = dname.fb_last_textures;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_LAST_DIR_TEXTURES, strptr, TRUE
-        );
-        strptr = dname.fb_last_view_background_image;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_LAST_DIR_VIEW_BACKGROUND_IMAGE,
+	strptr = dname.fb_last_models;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_LAST_DIR_MODELS, strptr, TRUE
+	);
+	strptr = dname.fb_last_textures;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_LAST_DIR_TEXTURES, strptr, TRUE
+	);
+	strptr = dname.fb_last_view_background_image;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_LAST_DIR_VIEW_BACKGROUND_IMAGE,
 	    strptr, TRUE
-        );
-        /* Scratchpad file. */
-        strptr = fname.scratchpad;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_FILE_SCRATCHPAD, strptr, TRUE
-        );
-        /* Plug-ins file. */
-        strptr = fname.plugins;
-        VMACFGItemListMatchSetValue(
-            option, VMA_CFG_PARM_FILE_PLUGINS, strptr, TRUE
-        );
+	);
+	/* Scratchpad file. */
+	strptr = fname.scratchpad;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_FILE_SCRATCHPAD, strptr, TRUE
+	);
+	/* Plug-ins file. */
+	strptr = fname.plugins;
+	VMACFGItemListMatchSetValue(
+	    option, VMA_CFG_PARM_FILE_PLUGINS, strptr, TRUE
+	);
 
 	/* Save plug-ins configuration file. */
-        VPISaveConfigurationToFile(
+	VPISaveConfigurationToFile(
 	    core_ptr->plugin, core_ptr->total_plugins,
 	    fname.plugins
 	);
@@ -1229,11 +1223,11 @@ int main(int argc, char *argv[])
 	/* Unload preset models. */
 	VMAPresetModelsUnload(core_ptr, &vma_preset_models);
 
-        /* Global pixmaps. */
-        VMAPixmapsListUnload(core_ptr, &vma_pixmaps_list);
+	/* Global pixmaps. */
+	VMAPixmapsListUnload(core_ptr, &vma_pixmaps_list);
 
-        /* File extension types list. */
-        VMADestroyFileTypes(&ftype);
+	/* File extension types list. */
+	VMADestroyFileTypes(&ftype);
 
 	/* GTK+ styles list. */
 	VMAStylesListDestroy(&styles_list);
@@ -1254,7 +1248,7 @@ int main(int argc, char *argv[])
 	 */
 	i = 0;
 	while(((&option[i])->type != VMA_CFG_ITEM_TYPE_NONE) ||
-              ((&option[i])->parameter != NULL)
+	      ((&option[i])->parameter != NULL)
 	)
 	{
 	    VMACFGItemResetValue(&option[i]);
