@@ -4,22 +4,22 @@
 #include <gtk/gtk.h>
 
 /*
- *	Menu map trigger type codes.
+ *	Menu map trigger type codes:
  */
-#define MENU_BUTTON_MAP_TYPE_PRESSED		0
-#define MENU_BUTTON_MAP_TYPE_PRESSED_DRAG	1
+#define MENU_BUTTON_MAP_TYPE_PRESSED		0	/* Map on press */
+#define MENU_BUTTON_MAP_TYPE_PRESSED_DRAG	1	/* Map on press and short drag */
 
 extern GtkWidget *MenuButtonNewH(
 	const gchar *label, guchar **icon_data,
 	GtkWidget **menu_rtn
 );
 extern GtkWidget *MenuButtonNewV(
-        const gchar *label, guchar **icon_data,
-        GtkWidget **menu_rtn
+	const gchar *label, guchar **icon_data,
+	GtkWidget **menu_rtn
 );
 extern GtkWidget *MenuButtonNewPixmap(
-        guchar **icon_data,
-        GtkWidget **menu_rtn
+	guchar **icon_data,
+	GtkWidget **menu_rtn
 );
 extern GtkWidget *MenuButtonGetMenu(GtkWidget *w);
 extern void MenuButtonSetMenu(GtkWidget *w, GtkMenu *menu);
