@@ -22,7 +22,7 @@
 \n\
     [file] is the V3D model file to load on startup.\n\
 \n\
-    [options] can be any of the following:
+    [options] can be any of the following:\n\
 \n\
         --rcfile <file>         Load configuration from <file>.\n\
         --config_file <file>    Same as --rcfile.\n\
@@ -43,7 +43,7 @@
 \n", \
  \
 	VMA_MSGNAME_STD_COPYRIGHT, \
-"Copyright (C) 1999-2001 WolfPack Entertainment.\n\
+"Copyright (C) 1999-2004 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosecuted\n\
