@@ -1,5 +1,5 @@
 /*
-                        Print Window Callbacks
+			Print Window Callbacks
  */
 
 #ifndef PRINTWINCB_H
@@ -11,12 +11,12 @@
 
 
 extern void PrintWinSourceTypeTextInsertCB(
-        GtkEditable *editable,
-        const gchar *text, gint length, gint *position,
-        gpointer data
+	GtkEditable *editable,
+	const gchar *text, gint length, gint *position,
+	gpointer data
 );
 extern void PrintWinPrintToToggleCB(GtkWidget *widget, gpointer data);
-extern void PrintWinPrintFileBrowseCB(void *widget, void *data);
+extern void PrintWinPrintFileBrowseCB(GtkWidget *widget, gpointer data);
 extern void PrintWinOrientationToggleCB(GtkWidget *widget, gpointer data);
 extern void PrintWinVisualToggleCB(GtkWidget *widget, gpointer data);
 extern void PrintWinPaperSizeToggleCB(GtkWidget *widget, gpointer data); 
