@@ -9,7 +9,7 @@
 #include <gtk/gtk.h>
 
 #ifndef gbool
-# define gbool	guchar
+# define gbool	gboolean
 #endif
 
 
