@@ -33,40 +33,40 @@ v3d_glresource_struct *V3DGLResourceNewFromModelData(
 	v3d_model_struct **model, int total_models
 );
 int V3DGLResourceSetInterpritation(
-        v3d_glresource_struct *glres,
-        const v3d_glinterprite_struct *glinterp
+	v3d_glresource_struct *glres,
+	const v3d_glinterprite_struct *glinterp
 );
 v3d_glinterprite_struct *V3DGLResourceGetInterpritation(
-        v3d_glresource_struct *glres  
+	v3d_glresource_struct *glres  
 );
 void V3DGLResourceDelete(v3d_glresource_struct *glres);
 
 /* V3D model to GL interpritation processing. */
 static void V3DGLSetNormal(
-        v3d_glinterprite_struct *glinterp, mp_vertex_struct *n
+	v3d_glinterprite_struct *glinterp, mp_vertex_struct *n
 );
 static void V3DGLSetTexCoord(
-        v3d_glinterprite_struct *glinterp, mp_vertex_struct *v,
-        mp_vertex_struct *tc, int texture_binded, void *p_texture_orient
+	v3d_glinterprite_struct *glinterp, mp_vertex_struct *v,
+	mp_vertex_struct *tc, int texture_binded, void *p_texture_orient
 );
 static void V3DGLSetVertex(
-        v3d_glinterprite_struct *glinterp, mp_vertex_struct *v
+	v3d_glinterprite_struct *glinterp, mp_vertex_struct *v
 );
 static void V3DGLProcessModelOtherData(
-        v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
-        v3d_model_struct *m,
-        void *client_data,
-        void (*extra_cb)(v3d_model_struct *, const char *, void *)
+	v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
+	v3d_model_struct *m,
+	void *client_data,
+	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 );
 static void V3DGLProcessModelStandard(
-        v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
-        v3d_model_struct *m,
-        void *client_data,
-        void (*extra_cb)(v3d_model_struct *, const char *, void *)
+	v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
+	v3d_model_struct *m,
+	void *client_data,
+	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 );
 void V3DGLProcessModelExtra(
-        v3d_glresource_struct *glres,
-        v3d_model_struct *m,
+	v3d_glresource_struct *glres,
+	v3d_model_struct *m,
 	void *client_data,
 	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 );
@@ -173,8 +173,8 @@ v3d_glresource_struct *V3DGLResourceNew(void)
  */
 v3d_glresource_struct *V3DGLResourceNewFromModelData(
 	const v3d_glinterprite_struct *glinterp,
-        void **mh_item, int total_mh_items,
-        v3d_model_struct **model, int total_models
+	void **mh_item, int total_mh_items,
+	v3d_model_struct **model, int total_models
 )
 {
 	int i, n;
@@ -254,7 +254,7 @@ v3d_glresource_struct *V3DGLResourceNewFromModelData(
 		    /* Texture loaded successfully. */
 
 		    /* Set texture priority. */
-		    V3DTexturePriority(t, h_texture_load->priority);
+		    V3DTexturePriority(t, (float)h_texture_load->priority);
 
 		    /* Allocate more texture pointers on GL resource. */
 		    n = glres->total_textures;
@@ -291,8 +291,8 @@ v3d_glresource_struct *V3DGLResourceNewFromModelData(
  *	Returns non-zero on error.
  */
 int V3DGLResourceSetInterpritation(
-        v3d_glresource_struct *glres,
-        const v3d_glinterprite_struct *glinterp
+	v3d_glresource_struct *glres,
+	const v3d_glinterprite_struct *glinterp
 )
 {
 	unsigned int flags;
@@ -314,44 +314,44 @@ int V3DGLResourceSetInterpritation(
 	if(flags & V3D_GLFLAG_COORDINATE_AXIS)
 	    t_glinterp->coordinate_axis = glinterp->coordinate_axis;
 
-        if(flags & V3D_GLFLAG_TEXTURE_KEEP)
-            t_glinterp->texture_keep = glinterp->texture_keep;
+	if(flags & V3D_GLFLAG_TEXTURE_KEEP)
+	    t_glinterp->texture_keep = glinterp->texture_keep;
 
 	if(flags & V3D_GLFLAG_ALLOW_TRANSLATIONS)
 	    t_glinterp->allow_translations = glinterp->allow_translations;
 
-        if(flags & V3D_GLFLAG_ALLOW_ROTATIONS)
-            t_glinterp->allow_rotations = glinterp->allow_rotations;
+	if(flags & V3D_GLFLAG_ALLOW_ROTATIONS)
+	    t_glinterp->allow_rotations = glinterp->allow_rotations;
 
 
-        if(flags & V3D_GLFLAG_FLIP_WINDING)
-            t_glinterp->flip_winding = glinterp->flip_winding;
+	if(flags & V3D_GLFLAG_FLIP_WINDING)
+	    t_glinterp->flip_winding = glinterp->flip_winding;
 
-        if(flags & V3D_GLFLAG_PASS_NORMALS)
-            t_glinterp->pass_normals = glinterp->pass_normals;
+	if(flags & V3D_GLFLAG_PASS_NORMALS)
+	    t_glinterp->pass_normals = glinterp->pass_normals;
 
-        if(flags & V3D_GLFLAG_UNITLIZE_NORMALS)
-            t_glinterp->unitlize_normals = glinterp->unitlize_normals;
+	if(flags & V3D_GLFLAG_UNITLIZE_NORMALS)
+	    t_glinterp->unitlize_normals = glinterp->unitlize_normals;
 
-        if(flags & V3D_GLFLAG_PASS_TEXCOORDS)
-            t_glinterp->pass_texcoords = glinterp->pass_texcoords;
+	if(flags & V3D_GLFLAG_PASS_TEXCOORDS)
+	    t_glinterp->pass_texcoords = glinterp->pass_texcoords;
 
-        if(flags & V3D_GLFLAG_TEXTURE_NAME_CASE_SENSITIVE)
+	if(flags & V3D_GLFLAG_TEXTURE_NAME_CASE_SENSITIVE)
 	    t_glinterp->texture_name_case_sensitive =
 		glinterp->texture_name_case_sensitive;
 
-        if(flags & V3D_GLFLAG_MATERIAL_PROPERTIES)
-            t_glinterp->material_properties = glinterp->material_properties;
+	if(flags & V3D_GLFLAG_MATERIAL_PROPERTIES)
+	    t_glinterp->material_properties = glinterp->material_properties;
 
-        if(flags & V3D_GLFLAG_FACES)
-            t_glinterp->faces = glinterp->faces;
+	if(flags & V3D_GLFLAG_FACES)
+	    t_glinterp->faces = glinterp->faces;
 
 
-        if(flags & V3D_GLFLAG_ENABLE_BLENDING)
-            t_glinterp->enable_blending = glinterp->enable_blending;
+	if(flags & V3D_GLFLAG_ENABLE_BLENDING)
+	    t_glinterp->enable_blending = glinterp->enable_blending;
 
-        if(flags & V3D_GLFLAG_SET_BLEND_FUNC)
-            t_glinterp->set_blend_func = glinterp->set_blend_func;
+	if(flags & V3D_GLFLAG_SET_BLEND_FUNC)
+	    t_glinterp->set_blend_func = glinterp->set_blend_func;
 
 	if(flags & V3D_GLFLAG_HEIGHTFIELD_BASE_DIR)
 	{
@@ -363,10 +363,10 @@ int V3DGLResourceSetInterpritation(
 
 	if(flags & V3D_GLFLAG_TEXTURE_BASE_DIR)
 	{
-            const char *src_str = glinterp->texture_base_dir;
+	    const char *src_str = glinterp->texture_base_dir;
 
-            free(t_glinterp->texture_base_dir);
-            t_glinterp->texture_base_dir = STRDUP(src_str);
+	    free(t_glinterp->texture_base_dir);
+	    t_glinterp->texture_base_dir = STRDUP(src_str);
 	}
 
 
@@ -385,7 +385,7 @@ int V3DGLResourceSetInterpritation(
  *	Can return NULL on error.
  */
 v3d_glinterprite_struct *V3DGLResourceGetInterpritation(
-        v3d_glresource_struct *glres  
+	v3d_glresource_struct *glres  
 )
 {
 	return((glres != NULL) ? glres->glinterprite : NULL);
@@ -442,9 +442,9 @@ static void V3DGLSetNormal(
 	    if(glinterp->flags & V3D_GLFLAG_COORDINATE_AXIS)
 		coordinate_axis = glinterp->coordinate_axis;
 	    if(glinterp->flags & V3D_GLFLAG_PASS_NORMALS)
-                pass_normals = glinterp->pass_normals;
-            if(glinterp->flags & V3D_GLFLAG_UNITLIZE_NORMALS)
-                unitlize_normals = glinterp->unitlize_normals;
+		pass_normals = glinterp->pass_normals;
+	    if(glinterp->flags & V3D_GLFLAG_UNITLIZE_NORMALS)
+		unitlize_normals = glinterp->unitlize_normals;
 	}
 
 	/* Never pass normals? */
@@ -469,7 +469,7 @@ static void V3DGLSetNormal(
 	tn.z = n->z;
 
 	if(unitlize_normals &&
-           ((tn.x != 0.0) || (tn.y != 0.0) || (tn.z != 0.0))
+	   ((tn.x != 0.0) || (tn.y != 0.0) || (tn.z != 0.0))
 	)
 	{
 	    double mag = SQRT(
@@ -504,31 +504,31 @@ static void V3DGLSetTexCoord(
 	mp_vertex_struct *tc, int texture_binded, void *p_texture_orient
 )
 {
-        int coordinate_axis = V3D_GLCOORDINATE_AXIS_SCIENTIFIC;
-        int pass_texcoords = V3D_GLPASS_TEXCOORDS_AS_NEEDED;
+	int coordinate_axis = V3D_GLCOORDINATE_AXIS_SCIENTIFIC;
+	int pass_texcoords = V3D_GLPASS_TEXCOORDS_AS_NEEDED;
 
-        if(tc == NULL)
-            return;
+	if(tc == NULL)
+	    return;
 
-        if(glinterp != NULL)
-        {
-            if(glinterp->flags & V3D_GLFLAG_COORDINATE_AXIS)
-                coordinate_axis = glinterp->coordinate_axis;
-            if(glinterp->flags & V3D_GLFLAG_PASS_TEXCOORDS)
-                pass_texcoords = glinterp->pass_texcoords;
-        }
+	if(glinterp != NULL)
+	{
+	    if(glinterp->flags & V3D_GLFLAG_COORDINATE_AXIS)
+		coordinate_axis = glinterp->coordinate_axis;
+	    if(glinterp->flags & V3D_GLFLAG_PASS_TEXCOORDS)
+		pass_texcoords = glinterp->pass_texcoords;
+	}
 
 	/* Never pass texcoords? */
 	if(pass_texcoords == V3D_GLPASS_TEXCOORDS_NEVER)
 	    return;
 
-        /* No texture is binded? */
-        if(!texture_binded)
-        {
-            /* No texture binded, check if we should pass texcoord. */
-            if(pass_texcoords != V3D_GLPASS_TEXCOORDS_ALWAYS)
-                return;
-        }
+	/* No texture is binded? */
+	if(!texture_binded)
+	{
+	    /* No texture binded, check if we should pass texcoord. */
+	    if(pass_texcoords != V3D_GLPASS_TEXCOORDS_ALWAYS)
+		return;
+	}
 
 	/* Orienting texcoord by plane? */
 	if((p_texture_orient != NULL) && (v != NULL))
@@ -542,7 +542,7 @@ static void V3DGLSetTexCoord(
 	    {
 	      case V3DMP_TYPE_TEXTURE_ORIENT_XY:
 		orient_xy = (mp_texture_orient_xy_struct *)p_texture_orient;
-                if(orient_xy->dx > 0.0)
+		if(orient_xy->dx > 0.0)
 		    s = (v->x - orient_xy->x) / orient_xy->dx;
 		else
 		    s = 0.0;
@@ -558,33 +558,33 @@ static void V3DGLSetTexCoord(
 
 	      case V3DMP_TYPE_TEXTURE_ORIENT_YZ:
 		orient_yz = (mp_texture_orient_yz_struct *)p_texture_orient;
-                if(orient_yz->dy > 0.0)
-                    s = -(v->y - orient_yz->y) / orient_yz->dy;
-                else
-                    s = 0.0;
-                if(orient_yz->dz > 0.0)
-                    t = (v->z - orient_yz->z) / orient_yz->dz;
-                else
-                    t = 0.0;
-                /* V3D texture coordinate origin is upper left while GL
-                 * is lower left, remember to flip the t.
-                 */
+		if(orient_yz->dy > 0.0)
+		    s = -(v->y - orient_yz->y) / orient_yz->dy;
+		else
+		    s = 0.0;
+		if(orient_yz->dz > 0.0)
+		    t = (v->z - orient_yz->z) / orient_yz->dz;
+		else
+		    t = 0.0;
+		/* V3D texture coordinate origin is upper left while GL
+		 * is lower left, remember to flip the t.
+		 */
 		glTexCoord2d(s, 1.0 - t);
 		break;
 
 	      case V3DMP_TYPE_TEXTURE_ORIENT_XZ:
 		orient_xz = (mp_texture_orient_xz_struct *)p_texture_orient;
-                if(orient_xz->dx > 0.0)
-                    s = (v->x - orient_xz->x) / orient_xz->dx;
-                else
-                    s = 0.0;
-                if(orient_xz->dz > 0.0)
-                    t = (v->z - orient_xz->z) / orient_xz->dz;
-                else
-                    t = 0.0;
-                /* V3D texture coordinate origin is upper left while GL
-                 * is lower left, remember to flip the t.
-                 */
+		if(orient_xz->dx > 0.0)
+		    s = (v->x - orient_xz->x) / orient_xz->dx;
+		else
+		    s = 0.0;
+		if(orient_xz->dz > 0.0)
+		    t = (v->z - orient_xz->z) / orient_xz->dz;
+		else
+		    t = 0.0;
+		/* V3D texture coordinate origin is upper left while GL
+		 * is lower left, remember to flip the t.
+		 */
 		glTexCoord2d(s, 1.0 - t);
 		break;
 	    }
@@ -595,19 +595,19 @@ static void V3DGLSetTexCoord(
 	    double s = tc->x;
 	    double t = tc->y;
 
-            /* V3D texture coordinate origin is upper left while GL
-             * is lower left, remember to flip the t.
-             */
-            switch(coordinate_axis)
-            {
-              case V3D_GLCOORDINATE_AXIS_GL:
-                glTexCoord2d(s, t);
-                break;
+	    /* V3D texture coordinate origin is upper left while GL
+	     * is lower left, remember to flip the t.
+	     */
+	    switch(coordinate_axis)
+	    {
+	      case V3D_GLCOORDINATE_AXIS_GL:
+		glTexCoord2d(s, t);
+		break;
 
-              case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
-                glTexCoord2d(s, 1.0 - t);
-                break;
-            }   
+	      case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
+		glTexCoord2d(s, 1.0 - t);
+		break;
+	    }   
 	}
 }
 
@@ -618,16 +618,16 @@ static void V3DGLSetVertex(
 	v3d_glinterprite_struct *glinterp, mp_vertex_struct *v
 )
 {
-        int coordinate_axis = V3D_GLCOORDINATE_AXIS_SCIENTIFIC;
+	int coordinate_axis = V3D_GLCOORDINATE_AXIS_SCIENTIFIC;
 
-        if(v == NULL)
-            return;
+	if(v == NULL)
+	    return;
 
-        if(glinterp != NULL)
-        {
-            if(glinterp->flags & V3D_GLFLAG_COORDINATE_AXIS)
-                coordinate_axis = glinterp->coordinate_axis;
-        }
+	if(glinterp != NULL)
+	{
+	    if(glinterp->flags & V3D_GLFLAG_COORDINATE_AXIS)
+		coordinate_axis = glinterp->coordinate_axis;
+	}
 
 	switch(coordinate_axis)
 	{
@@ -649,10 +649,10 @@ static void V3DGLSetVertex(
  *	Given inputs glres, glinterp, and m are assumed valid.
  */
 static void V3DGLProcessModelOtherData(
-        v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
-        v3d_model_struct *m,
-        void *client_data,
-        void (*extra_cb)(v3d_model_struct *, const char *, void *)
+	v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
+	v3d_model_struct *m,
+	void *client_data,
+	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 )
 {
 	int line_num;
@@ -677,14 +677,14 @@ static void V3DGLProcessModelOtherData(
  *      Given inputs glres, glinterp, and m are assumed valid.
  */
 static void V3DGLProcessModelStandard(
-        v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
-        v3d_model_struct *m,
-        void *client_data,
-        void (*extra_cb)(v3d_model_struct *, const char *, void *)
+	v3d_glresource_struct *glres, v3d_glinterprite_struct *glinterp,
+	v3d_model_struct *m,
+	void *client_data,
+	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 )
 {       
-        int pn, line_num;
-        const char *line_ptr;   
+	int pn, line_num;
+	const char *line_ptr;   
 	void *p;
 	int matrix_level = 0;
 	int texture_binded = FALSE;
@@ -700,7 +700,7 @@ static void V3DGLProcessModelStandard(
 	int faces = V3D_GLFACES_FRONT_AND_BACK;
 	int blending_enabled = FALSE;
 	int set_blend_func = FALSE;
-        const char *heightfield_base_dir = NULL;
+	const char *heightfield_base_dir = NULL;
 	const char *texture_base_dir = NULL;
 
 	int last_begin_ptype = -1;
@@ -735,11 +735,11 @@ static void V3DGLProcessModelStandard(
 	if(glinterp->flags & V3D_GLFLAG_FLIP_WINDING)
 	    flip_winding = glinterp->flip_winding;
 	if(glinterp->flags & V3D_GLFLAG_PASS_NORMALS)
-            pass_normals = glinterp->pass_normals;
-        if(glinterp->flags & V3D_GLFLAG_UNITLIZE_NORMALS)
-            unitlize_normals = glinterp->unitlize_normals;
-        if(glinterp->flags & V3D_GLFLAG_PASS_TEXCOORDS)
-            pass_texcoords = glinterp->pass_texcoords;
+	    pass_normals = glinterp->pass_normals;
+	if(glinterp->flags & V3D_GLFLAG_UNITLIZE_NORMALS)
+	    unitlize_normals = glinterp->unitlize_normals;
+	if(glinterp->flags & V3D_GLFLAG_PASS_TEXCOORDS)
+	    pass_texcoords = glinterp->pass_texcoords;
 	if(glinterp->flags & V3D_GLFLAG_TEXTURE_NAME_CASE_SENSITIVE)
 	    texture_name_case_sensitive = glinterp->texture_name_case_sensitive;
 	if(glinterp->flags & V3D_GLFLAG_MATERIAL_PROPERTIES)
@@ -748,8 +748,8 @@ static void V3DGLProcessModelStandard(
 	    faces = glinterp->faces;
 	if(glinterp->flags & V3D_GLFLAG_ENABLE_BLENDING)
 	    enable_blending = glinterp->enable_blending;
-        if(glinterp->flags & V3D_GLFLAG_SET_BLEND_FUNC)
-            set_blend_func = glinterp->set_blend_func;
+	if(glinterp->flags & V3D_GLFLAG_SET_BLEND_FUNC)
+	    set_blend_func = glinterp->set_blend_func;
 	if(glinterp->flags & V3D_GLFLAG_HEIGHTFIELD_BASE_DIR)
 	    heightfield_base_dir = glinterp->heightfield_base_dir;
 	if(glinterp->flags & V3D_GLFLAG_TEXTURE_BASE_DIR)
@@ -757,9 +757,9 @@ static void V3DGLProcessModelStandard(
 
 
 	/* Iterate through each primitive on the given editor. */
-        for(pn = 0; pn < m->total_primitives; pn++)
+	for(pn = 0; pn < m->total_primitives; pn++)
 	{
-            p = m->primitive[pn];
+	    p = m->primitive[pn];
 	    if(p == NULL)
 		continue;
 
@@ -767,7 +767,7 @@ static void V3DGLProcessModelStandard(
 	     * new primitive type.
 	     */
 	    if((last_begin_ptype != V3DMPGetType(p)) &&
-               (last_begin_ptype > -1)
+	       (last_begin_ptype > -1)
 	    )
 	    {
 		glEnd();
@@ -780,7 +780,7 @@ static void V3DGLProcessModelStandard(
 	    {
 	      case V3DMP_TYPE_COMMENT:
 		p_comment = (mp_comment_struct *)p;
-                for(line_num = 0; line_num < p_comment->total_lines; line_num++)
+		for(line_num = 0; line_num < p_comment->total_lines; line_num++)
 		{
 		    line_ptr = (const char *)p_comment->line[line_num];
 		    if(line_ptr == NULL)
@@ -809,79 +809,79 @@ static void V3DGLProcessModelStandard(
 		    );
 		    break;
 
-                  case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
-                    glTranslated(
-                        p_translate->x, p_translate->z, -p_translate->y
-                    );
-                    break;
+		  case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
+		    glTranslated(
+			p_translate->x, p_translate->z, -p_translate->y
+		    );
+		    break;
 		}
 		break;
 
 	      case V3DMP_TYPE_UNTRANSLATE:
 		p_untranslate = (mp_untranslate_struct *)p;
-                if(glinterp->flags & V3D_GLFLAG_ALLOW_TRANSLATIONS)
-                {
-                    if(!glinterp->allow_translations)
-                        break;
-                }
+		if(glinterp->flags & V3D_GLFLAG_ALLOW_TRANSLATIONS)
+		{
+		    if(!glinterp->allow_translations)
+			break;
+		}
 		glPopMatrix();
 		matrix_level--;
 		break;
 
-              case V3DMP_TYPE_ROTATE:
-                p_rotate = (mp_rotate_struct *)p;
-                if(glinterp->flags & V3D_GLFLAG_ALLOW_ROTATIONS)
-                {
-                    if(!glinterp->allow_rotations)
-                        break;
-                }
-                glPushMatrix();
-                matrix_level++;
+	      case V3DMP_TYPE_ROTATE:
+		p_rotate = (mp_rotate_struct *)p;
+		if(glinterp->flags & V3D_GLFLAG_ALLOW_ROTATIONS)
+		{
+		    if(!glinterp->allow_rotations)
+			break;
+		}
+		glPushMatrix();
+		matrix_level++;
 
-                switch(coordinate_axis)
-                {
-                  case V3D_GLCOORDINATE_AXIS_GL:
-                    glRotated(
-                        -RADTODEG(p_rotate->heading),
-                        0.0, 0.0, 1.0
-                    );
-                    glRotated(
-                        -RADTODEG(p_rotate->pitch),
-                        1.0, 0.0, 0.0
-                    );
-                    glRotated(
-                       -RADTODEG(p_rotate->bank),
-                        0.0, 1.0, 0.0
-                    );
+		switch(coordinate_axis)
+		{
+		  case V3D_GLCOORDINATE_AXIS_GL:
+		    glRotated(
+			-RADTODEG(p_rotate->heading),
+			0.0, 0.0, 1.0
+		    );
+		    glRotated(
+			-RADTODEG(p_rotate->pitch),
+			1.0, 0.0, 0.0
+		    );
+		    glRotated(
+		       -RADTODEG(p_rotate->bank),
+			0.0, 1.0, 0.0
+		    );
 		    break;
 
-                  case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
-                    glRotated(
-                        -RADTODEG(p_rotate->heading),
-                        0.0, 1.0, 0.0
-                    );
-                    glRotated(
-                        -RADTODEG(p_rotate->pitch),
-                        1.0, 0.0, 0.0
-                    );
-                    glRotated(
-                       -RADTODEG(p_rotate->bank),
-                        0.0, 0.0, 1.0
-                    );
-                    break;
+		  case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
+		    glRotated(
+			-RADTODEG(p_rotate->heading),
+			0.0, 1.0, 0.0
+		    );
+		    glRotated(
+			-RADTODEG(p_rotate->pitch),
+			1.0, 0.0, 0.0
+		    );
+		    glRotated(
+		       -RADTODEG(p_rotate->bank),
+			0.0, 0.0, 1.0
+		    );
+		    break;
 		}
-                break;
+		break;
 
-              case V3DMP_TYPE_UNROTATE:
-                p_unrotate = (mp_unrotate_struct *)p;
-                if(glinterp->flags & V3D_GLFLAG_ALLOW_ROTATIONS)
-                {
-                    if(!glinterp->allow_rotations)
-                        break;
-                }
-                glPopMatrix();
-                matrix_level--;
-                break;
+	      case V3DMP_TYPE_UNROTATE:
+		p_unrotate = (mp_unrotate_struct *)p;
+		if(glinterp->flags & V3D_GLFLAG_ALLOW_ROTATIONS)
+		{
+		    if(!glinterp->allow_rotations)
+			break;
+		}
+		glPopMatrix();
+		matrix_level--;
+		break;
 
 #define DO_SET_VERTEX_DYNAMIC	\
 { \
@@ -1033,107 +1033,107 @@ static void V3DGLProcessModelStandard(
 #undef V_TOTAL
 		break;
 
-              case V3DMP_TYPE_LINE:
+	      case V3DMP_TYPE_LINE:
 #define P_PTR   p_line
 #define V_TOTAL V3DMP_LINE_NVERTEX
-                P_PTR = (mp_line_struct *)p;
-                if(last_begin_ptype != V3DMP_TYPE_LINE)
-                    glBegin(GL_LINES);
-                DO_SET_VERTEX_STATIC
-                last_begin_ptype = V3DMP_TYPE_LINE;
+		P_PTR = (mp_line_struct *)p;
+		if(last_begin_ptype != V3DMP_TYPE_LINE)
+		    glBegin(GL_LINES);
+		DO_SET_VERTEX_STATIC
+		last_begin_ptype = V3DMP_TYPE_LINE;
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_LINE_STRIP:
+	      case V3DMP_TYPE_LINE_STRIP:
 #define P_PTR   p_line_strip
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_line_strip_struct *)p;
-                glBegin(GL_LINE_STRIP);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		P_PTR = (mp_line_strip_struct *)p;
+		glBegin(GL_LINE_STRIP);
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_LINE_LOOP:
+	      case V3DMP_TYPE_LINE_LOOP:
 #define P_PTR   p_line_loop
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_line_loop_struct *)p;
-                glBegin(GL_LINE_LOOP);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		P_PTR = (mp_line_loop_struct *)p;
+		glBegin(GL_LINE_LOOP);
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_TRIANGLE:
+	      case V3DMP_TYPE_TRIANGLE:
 #define P_PTR   p_triangle
 #define V_TOTAL V3DMP_TRIANGLE_NVERTEX
-                P_PTR = (mp_triangle_struct *)p;
-                if(last_begin_ptype != V3DMP_TYPE_TRIANGLE)
-                    glBegin(GL_TRIANGLES);
-                DO_SET_VERTEX_STATIC
-                last_begin_ptype = V3DMP_TYPE_TRIANGLE;
+		P_PTR = (mp_triangle_struct *)p;
+		if(last_begin_ptype != V3DMP_TYPE_TRIANGLE)
+		    glBegin(GL_TRIANGLES);
+		DO_SET_VERTEX_STATIC
+		last_begin_ptype = V3DMP_TYPE_TRIANGLE;
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_TRIANGLE_STRIP:
+	      case V3DMP_TYPE_TRIANGLE_STRIP:
 #define P_PTR   p_triangle_strip
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_triangle_strip_struct *)p;
-                glBegin(GL_TRIANGLE_STRIP);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		P_PTR = (mp_triangle_strip_struct *)p;
+		glBegin(GL_TRIANGLE_STRIP);
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_TRIANGLE_FAN:
+	      case V3DMP_TYPE_TRIANGLE_FAN:
 #define P_PTR   p_triangle_fan
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_triangle_fan_struct *)p;
-                glBegin(GL_TRIANGLE_FAN);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		P_PTR = (mp_triangle_fan_struct *)p;
+		glBegin(GL_TRIANGLE_FAN);
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_QUAD:
+	      case V3DMP_TYPE_QUAD:
 #define P_PTR   p_quad
 #define V_TOTAL V3DMP_QUAD_NVERTEX
-                P_PTR = (mp_quad_struct *)p;
-                if(last_begin_ptype != V3DMP_TYPE_QUAD)
-                    glBegin(GL_QUADS);
-                DO_SET_VERTEX_STATIC
-                last_begin_ptype = V3DMP_TYPE_QUAD;
+		P_PTR = (mp_quad_struct *)p;
+		if(last_begin_ptype != V3DMP_TYPE_QUAD)
+		    glBegin(GL_QUADS);
+		DO_SET_VERTEX_STATIC
+		last_begin_ptype = V3DMP_TYPE_QUAD;
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_QUAD_STRIP:
+	      case V3DMP_TYPE_QUAD_STRIP:
 #define P_PTR   p_quad_strip
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_quad_strip_struct *)p;
-                glBegin(GL_QUAD_STRIP);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		P_PTR = (mp_quad_strip_struct *)p;
+		glBegin(GL_QUAD_STRIP);
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
-              case V3DMP_TYPE_POLYGON:
+	      case V3DMP_TYPE_POLYGON:
 #define P_PTR   p_polygon
 #define V_TOTAL P_PTR->total
-                P_PTR = (mp_polygon_struct *)p;
+		P_PTR = (mp_polygon_struct *)p;
 		glBegin(GL_POLYGON);
-                DO_SET_VERTEX_DYNAMIC
-                glEnd();
+		DO_SET_VERTEX_DYNAMIC
+		glEnd();
 #undef P_PTR
 #undef V_TOTAL
-                break;
+		break;
 
 #undef DO_SET_VERTEX_STATIC
 #undef DO_SET_VERTEX_DYNAMIC
@@ -1148,24 +1148,26 @@ static void V3DGLProcessModelStandard(
 			if(!blending_enabled)
 			{
 			    glEnable(GL_BLEND);
+			    glDisable(GL_ALPHA_TEST);
 			    blending_enabled = TRUE;
 			}
 		    }
-                    if(set_blend_func)
-                    {
-/* Need to work on this. */
-                    }
+		    if(set_blend_func)
+		    {
+			glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+		    }
 		}
 		else
 		{
-                    if(enable_blending)
-                    {
-                        if(blending_enabled)
-                        {   
-                            glDisable(GL_BLEND);
+		    if(enable_blending)
+		    {
+			if(blending_enabled)
+			{   
+			    glDisable(GL_BLEND);
+			    glEnable(GL_ALPHA_TEST);
 			    blending_enabled = FALSE;
-                        }
-                    }
+			}
+		    }
 		}
 		/* Set color? */
 		if(material_properties != V3D_GLPASS_MATERIAL_PROPERTIES_INSTEAD_COLOR)
@@ -1183,40 +1185,40 @@ static void V3DGLProcessModelStandard(
 		      case V3D_GLFACES_FRONT_AND_BACK:
 			glface = GL_FRONT_AND_BACK;
 			break;
-                      case V3D_GLFACES_BACK:
-                        glface = GL_BACK;
-                        break;
-                      default:	/* V3D_GLFACES_FRONT */
-                        glface = GL_FRONT;
-                        break;
+		      case V3D_GLFACES_BACK:
+			glface = GL_BACK;
+			break;
+		      default:	/* V3D_GLFACES_FRONT */
+			glface = GL_FRONT;
+			break;
 		    }
 
 		    glparam[0] = (GLfloat)(p_color->ambient * p_color->r);
-                    glparam[1] = (GLfloat)(p_color->ambient * p_color->g);
-                    glparam[2] = (GLfloat)(p_color->ambient * p_color->b);
-                    glparam[3] = (GLfloat)(p_color->a);
+		    glparam[1] = (GLfloat)(p_color->ambient * p_color->g);
+		    glparam[2] = (GLfloat)(p_color->ambient * p_color->b);
+		    glparam[3] = (GLfloat)(p_color->a);
 		    glMaterialfv(glface, GL_AMBIENT, glparam);
 
-                    glparam[0] = (GLfloat)(p_color->diffuse * p_color->r);
-                    glparam[1] = (GLfloat)(p_color->diffuse * p_color->g);
-                    glparam[2] = (GLfloat)(p_color->diffuse * p_color->b);
-                    glparam[3] = (GLfloat)(p_color->a);
-                    glMaterialfv(glface, GL_DIFFUSE, glparam);
+		    glparam[0] = (GLfloat)(p_color->diffuse * p_color->r);
+		    glparam[1] = (GLfloat)(p_color->diffuse * p_color->g);
+		    glparam[2] = (GLfloat)(p_color->diffuse * p_color->b);
+		    glparam[3] = (GLfloat)(p_color->a);
+		    glMaterialfv(glface, GL_DIFFUSE, glparam);
 
-                    glparam[0] = (GLfloat)(p_color->specular * p_color->r);
-                    glparam[1] = (GLfloat)(p_color->specular * p_color->g);
-                    glparam[2] = (GLfloat)(p_color->specular * p_color->b);
-                    glparam[3] = (GLfloat)(p_color->a);
-                    glMaterialfv(glface, GL_SPECULAR, glparam);
+		    glparam[0] = (GLfloat)(p_color->specular * p_color->r);
+		    glparam[1] = (GLfloat)(p_color->specular * p_color->g);
+		    glparam[2] = (GLfloat)(p_color->specular * p_color->b);
+		    glparam[3] = (GLfloat)(p_color->a);
+		    glMaterialfv(glface, GL_SPECULAR, glparam);
 
-                    glparam[0] = (GLfloat)(p_color->shininess * 128.0);
-                    glMaterialf(glface, GL_SHININESS, glparam[0]);
+		    glparam[0] = (GLfloat)(p_color->shininess * 128.0);
+		    glMaterialf(glface, GL_SHININESS, glparam[0]);
  
-                    glparam[0] = (GLfloat)(p_color->emission * p_color->r);
-                    glparam[1] = (GLfloat)(p_color->emission * p_color->g);
-                    glparam[2] = (GLfloat)(p_color->emission * p_color->b);
-                    glparam[3] = (GLfloat)(p_color->a);
-                    glMaterialfv(glface, GL_EMISSION, glparam);
+		    glparam[0] = (GLfloat)(p_color->emission * p_color->r);
+		    glparam[1] = (GLfloat)(p_color->emission * p_color->g);
+		    glparam[2] = (GLfloat)(p_color->emission * p_color->b);
+		    glparam[3] = (GLfloat)(p_color->a);
+		    glMaterialfv(glface, GL_EMISSION, glparam);
 		}
 		break;
 
@@ -1249,8 +1251,8 @@ static void V3DGLProcessModelStandard(
 			}
 			else
 			{
-                            if(!strcasecmp(t->name, tex_name))
-                                break;
+			    if(!strcasecmp(t->name, tex_name))
+				break;
 			}
 		    }
 		    /* Matched texture? */
@@ -1281,28 +1283,28 @@ static void V3DGLProcessModelStandard(
 		}
 		break;
 
-              case V3DMP_TYPE_TEXTURE_ORIENT_YZ:
-                p_texture_orient_yz = (mp_texture_orient_yz_struct *)p;
-                if(texture_binded)
-                {
-                    last_p_texture_orient = p;
-                }
-                break;
+	      case V3DMP_TYPE_TEXTURE_ORIENT_YZ:
+		p_texture_orient_yz = (mp_texture_orient_yz_struct *)p;
+		if(texture_binded)
+		{
+		    last_p_texture_orient = p;
+		}
+		break;
 
-              case V3DMP_TYPE_TEXTURE_ORIENT_XZ:
-                p_texture_orient_xz = (mp_texture_orient_xz_struct *)p;
-                if(texture_binded)
-                {
-                    last_p_texture_orient = p;
-                }
-                break;
+	      case V3DMP_TYPE_TEXTURE_ORIENT_XZ:
+		p_texture_orient_xz = (mp_texture_orient_xz_struct *)p;
+		if(texture_binded)
+		{
+		    last_p_texture_orient = p;
+		}
+		break;
 
-              case V3DMP_TYPE_TEXTURE_OFF:
-                p_texture_off = (mp_texture_off_struct *)p;
+	      case V3DMP_TYPE_TEXTURE_OFF:
+		p_texture_off = (mp_texture_off_struct *)p;
 		V3DTextureSelect(NULL);
-                texture_binded = FALSE;
+		texture_binded = FALSE;
 		last_p_texture_orient = NULL;
-                break;
+		break;
 
 	      case V3DMP_TYPE_HEIGHTFIELD_LOAD:
 		p_heightfield_load = (mp_heightfield_load_struct *)p;
@@ -1343,26 +1345,26 @@ static void V3DGLProcessModelStandard(
 			    p_heightfield_load->y,
 			    p_heightfield_load->z
 			);
-                        glRotated(
-                            -RADTODEG(p_heightfield_load->heading),
-                            0.0, 0.0, 1.0 
-                        );
-                        glRotated(
-                            -RADTODEG(p_heightfield_load->pitch),  
-                            1.0, 0.0, 0.0
-                        );
-                        glRotated(
-                            -RADTODEG(p_heightfield_load->bank),
-                            0.0, 1.0, 0.0
-                        );
+			glRotated(
+			    -RADTODEG(p_heightfield_load->heading),
+			    0.0, 0.0, 1.0 
+			);
+			glRotated(
+			    -RADTODEG(p_heightfield_load->pitch),  
+			    1.0, 0.0, 0.0
+			);
+			glRotated(
+			    -RADTODEG(p_heightfield_load->bank),
+			    0.0, 1.0, 0.0
+			);
 			break;
 
-                      case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
-                        glTranslated(
-                            p_heightfield_load->x, 
-                            p_heightfield_load->z,
-                            -p_heightfield_load->y
-                        );
+		      case V3D_GLCOORDINATE_AXIS_SCIENTIFIC:
+			glTranslated(
+			    p_heightfield_load->x, 
+			    p_heightfield_load->z,
+			    -p_heightfield_load->y
+			);
 			glRotated(
 			    -RADTODEG(p_heightfield_load->heading),
 			    0.0, 1.0, 0.0
@@ -1375,7 +1377,7 @@ static void V3DGLProcessModelStandard(
 			    -RADTODEG(p_heightfield_load->bank),
 			    0.0, 0.0, 1.0
 			);
-                        break;
+			break;
 		    }
 
 		    /* Set up heightfield options. */
@@ -1385,10 +1387,10 @@ static void V3DGLProcessModelStandard(
 		    hfopt.winding = ((flip_winding) ?
 			V3D_HF_WIND_CCW : V3D_HF_WIND_CW
 		    );
-                    hfopt.set_normal = ((pass_normals != V3D_GLPASS_NORMALS_NEVER) ?
+		    hfopt.set_normal = ((pass_normals != V3D_GLPASS_NORMALS_NEVER) ?
 			V3D_HF_SET_NORMAL_AVERAGED : V3D_HF_SET_NORMAL_NEVER
 		    );
-                    hfopt.set_texcoord = ((pass_texcoords != V3D_GLPASS_TEXCOORDS_NEVER) ?
+		    hfopt.set_texcoord = ((pass_texcoords != V3D_GLPASS_TEXCOORDS_NEVER) ?
 			V3D_HF_SET_TEXCOORD_ALWAYS : V3D_HF_SET_TEXCOORD_NEVER
 		    );
 
@@ -1419,19 +1421,24 @@ static void V3DGLProcessModelStandard(
 	    last_begin_ptype = -1;
 	}
 
-	/* Pop any extranous matrixes. */
+	/* Pop any extranous matrixes */
 	while(matrix_level > 0)
 	{
 	    glPopMatrix();
 	    matrix_level--;
 	}
 
-	/* Unbind any textures. */
+	/* Unbind any textures */
 	if(texture_binded)
 	    V3DTextureSelect(NULL);
 
+	/* Restore blend state */
 	if(blending_enabled)
+	{
 	    glDisable(GL_BLEND);
+	    glEnable(GL_ALPHA_TEST);
+	    blending_enabled = FALSE;
+	}
 }
 
 /*
@@ -1441,10 +1448,10 @@ static void V3DGLProcessModelStandard(
  *	function.
  */
 void V3DGLProcessModelExtra(
-        v3d_glresource_struct *glres,
-        v3d_model_struct *m,
-        void *client_data,
-        void (*extra_cb)(v3d_model_struct *, const char *, void *)
+	v3d_glresource_struct *glres,
+	v3d_model_struct *m,
+	void *client_data,
+	void (*extra_cb)(v3d_model_struct *, const char *, void *)
 )
 {
 	v3d_glinterprite_struct *glinterp;
@@ -1471,9 +1478,9 @@ void V3DGLProcessModelExtra(
 	    break;
 
 	  case V3D_MODEL_TYPE_STANDARD:
-            V3DGLProcessModelStandard(
-                glres, glinterp, m, client_data, extra_cb
-            );
+	    V3DGLProcessModelStandard(
+		glres, glinterp, m, client_data, extra_cb
+	    );
 	    break;
 	}
 }
@@ -1483,8 +1490,8 @@ void V3DGLProcessModelExtra(
  *	extranous data callback.
  */
 void V3DGLProcessModel(
-        v3d_glresource_struct *glres,
-        v3d_model_struct *m
+	v3d_glresource_struct *glres,
+	v3d_model_struct *m
 )
 {
 	V3DGLProcessModelExtra(glres, m, NULL, NULL);
