@@ -126,7 +126,7 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
 	    return;
 
 
-	/* Stop all print jobs. */
+	/* Stop all print jobs */
 	for(i = 0; i < core_ptr->total_print_jobs; i++)
 	    PrintJobDelete(core_ptr->print_job[i]);
 	g_free(core_ptr->print_job);
@@ -134,7 +134,7 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
 	core_ptr->total_print_jobs = 0;
 
 
-	/* Remove GTK+ idle and timeout callbacks. */
+	/* Remove GTK+ idle and timeout callbacks */
 #define DO_REMOVE_TOID		\
 { \
  if((*toid) != (guint)(-1)) \
@@ -158,8 +158,8 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
 	toid = &core_ptr->plugin_manage_toid;
 	DO_REMOVE_TOID
 /*
-        idleid = &core_ptr->plugin_manage_idleid;
-        DO_REMOVE_IDLEID
+	idleid = &core_ptr->plugin_manage_idleid;
+	DO_REMOVE_IDLEID
  */
 #undef DO_REMOVE_TOID
 #undef DO_REMOVE_IDLEID
@@ -177,16 +177,16 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
 	core_ptr->total_plugins = 0;
 
 
-	/* No more reenterant resources exist from this point on. */
+	/* No more reenterant resources exist from this point on */
 
-	/* Delete scratch pad. */
+	/* Delete scratch pad */
 	if(core_ptr->scratch_pad != NULL)
 	{
 	    ScratchPadDelete(core_ptr->scratch_pad);
 	    core_ptr->scratch_pad = NULL;
 	}
 
-	/* Delete all editor structures. */
+	/* Delete all editor structures */
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    editor = core_ptr->editor[i];
@@ -199,28 +199,28 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
 	core_ptr->editor = NULL;
 	core_ptr->total_editors = 0;
 
-	/* Delete preferences window. */
+	/* Delete preferences window */
 	if(core_ptr->pref_win != NULL)
 	{
 	    PrefDelete(core_ptr->pref_win);
 	    core_ptr->pref_win = NULL;
 	}
 
-	/* Delete print window. */
+	/* Delete print window */
 	if(core_ptr->print_win != NULL)
 	{
 	    PrintWinDelete(core_ptr->print_win);
 	    core_ptr->print_win = NULL;
 	}
 
-	/* Delete about dialog. */
+	/* Delete about dialog */
 	if(core_ptr->about_dialog != NULL)
 	{
 	    AboutDialogDelete(core_ptr->about_dialog);
 	    core_ptr->about_dialog = NULL;
 	}
 
-	/* Delete tip of day window. */
+	/* Delete tip of day window */
 	if(core_ptr->todwin != NULL)
 	{
 	    TODWinDelete(core_ptr->todwin);
@@ -257,160 +257,139 @@ void VMAShutdownCB(vma_core_struct *core_ptr)
  */
 gint VMATimeoutCB(gpointer data)
 {
-	static gbool reenterant = FALSE;
 	gbool still_processing, has_changes, all_unmapped;
 	gint i;
 	guint *toid;
-/*	guint *idleid; */
 	GtkWidget *transient_for_w = NULL;
 	ma_editor_struct *editor;
 	vma_pref_struct *pref_win;
 	print_win_struct *print_win;
-        print_job_struct *pj;
+	print_job_struct *pj;
 	vma_core_struct *core_ptr = (vma_core_struct *)data;
 	if(core_ptr == NULL)
 	    return(FALSE);
 
-	if(reenterant)
-	    return(TRUE);
-	else
-	    reenterant = TRUE;
 
-
-/* Macro to remove the timeout id pointed to by toid. */
-#define DO_REMOVE_TOID		\
-{ \
- if((*toid) != (guint)(-1)) \
- { \
-  gtk_timeout_remove(*toid); \
-  (*toid) = (guint)(-1); \
- } \
+/* Macro to remove the timeout id pointed to by toid */
+#define DO_REMOVE_TOID {		\
+ if(*toid != (guint)(-1)) {		\
+  gtk_timeout_remove(*toid);		\
+  *toid = (guint)(-1);			\
+ }					\
 }
-#define DO_REMOVE_IDLEID	\
-{ \
- if((*idleid) != (guint)(-1)) \
- { \
-  gtk_idle_remove(*idleid); \
-  (*idleid) = (guint)(-1); \
- } \
+#define DO_REMOVE_IDLEID	{	\
+ if(*idleid != (guint)(-1)) {		\
+  gtk_idle_remove(*idleid);		\
+  *idleid = (guint)(-1);		\
+ }					\
 }
 
-/* Macro to remove all timeout callbacks and call gtk_main_quit(). */
-#define DO_GTK_MAIN_QUIT	\
-{ \
- /* Remove GTK+ timeout callbacks. */ \
- toid = &vma_manage_toid; \
- DO_REMOVE_TOID \
- \
- toid = &core_ptr->backup_toid; \
- DO_REMOVE_TOID \
- \
- toid = &core_ptr->plugin_manage_toid; \
- DO_REMOVE_TOID \
-/* \
- idleid = &core_ptr->plugin_manage_idleid; \
- DO_REMOVE_IDLEID \
- */ \
- \
- /* Flush GTK+ events. */ \
- while(gtk_events_pending() > 0) \
-  gtk_main_iteration(); \
- \
- /* Break out of main GTK+ loop. */ \
- gtk_main_quit(); \
+/* Macro to remove all timeout callbacks and call gtk_main_quit() */
+#define DO_GTK_MAIN_QUIT	{		\
+ /* Remove GTK timeout callbacks */		\
+ toid = &vma_manage_toid;			\
+ DO_REMOVE_TOID					\
+						\
+ toid = &core_ptr->backup_toid;			\
+ DO_REMOVE_TOID					\
+						\
+ toid = &core_ptr->plugin_manage_toid;		\
+ DO_REMOVE_TOID					\
+/*						\
+ idleid = &core_ptr->plugin_manage_idleid;	\
+ DO_REMOVE_IDLEID				\
+ */						\
+						\
+ /* Flush GTK events */				\
+ while(gtk_events_pending() > 0)		\
+  gtk_main_iteration();				\
+						\
+ /* Break out of main GTK+ loop */		\
+ gtk_main_quit();				\
 }
 
-/* Macro to reschedual timeout callback to this function and return FALSE. */
-#define DO_RETURN_RESCHEDUAL	\
-{ \
- /* Reschedual call to this function. */ \
- vma_manage_toid = gtk_timeout_add( \
-  1000,	/* 1 second interval. */ \
-  (GtkFunction)VMATimeoutCB, \
-  core_ptr \
- ); \
-\
- reenterant = FALSE; \
- /* Its okay to return FALSE because we just reschedualed another call to \
-  * this function above. \
-  */ \
- return(FALSE); \
+/* Macro to reschedual timeout callback to this function and return FALSE */
+#define DO_RETURN_RESCHEDUAL	{		\
+ /* Reschedual call to this function and	\
+  * return FALSE				\
+  */						\
+ vma_manage_toid = gtk_timeout_add(		\
+  1000l,	/* 1 second interval */		\
+  VMATimeoutCB, core_ptr			\
+ );						\
+ return(FALSE);					\
 }
 
 /* Macro to return FALSE, thus removing the timeout callback to this
  * function.
  */
-#define DO_RETURN_NO_RESCHEDUAL	\
-{ \
- vma_manage_toid = (guint)-1; \
- reenterant = FALSE; \
- return(FALSE); \
+#define DO_RETURN_NO_RESCHEDUAL	{		\
+ vma_manage_toid = (guint)-1;			\
+ return(FALSE);					\
 }
 
 /* Macro to return TRUE, keeping the current timeout callback to this
  * function.
  */
-#define DO_RETURN_CURRENT_SCHEDUAL	\
-{ \
- reenterant = FALSE; \
- return(TRUE); \
+#define DO_RETURN_CURRENT_SCHEDUAL	{	\
+ return(TRUE);					\
 }
 
 
-        /* Need to close all windows? */
+	/* Need to close all windows? */
 	if(need_close_all_windows)
 	{
-            /* Check if any dialogs are in query, break query as needed
-             * and return. Let next call to this function handle rest of
-             * closing all windows.
-             */   
-            if(CDialogIsQuery())
-            {
-                CDialogBreakQuery();
+	    /* Check if any dialogs are in query, break query as needed
+	     * and return. Let next call to this function handle rest of
+	     * closing all windows.
+	     */   
+	    if(CDialogIsQuery())
+	    {
+		CDialogBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(FileBrowserIsQuery())
-            {
-                FileBrowserBreakQuery();
+	    }
+	    if(FileBrowserIsQuery())
+	    {
+		FileBrowserBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(ProgressDialogIsQuery())
-            {
-                ProgressDialogBreakQuery(FALSE);
+	    }
+	    if(ProgressDialogIsQuery())
+	    {
+		ProgressDialogBreakQuery(FALSE);
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(FSDIsQuery())
-            {
-                FSDBreakQuery();
+	    }
+	    if(FSDIsQuery())
+	    {
+		FSDBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(CSDIsQuery())
-            {
-                CSDBreakQuery();
+	    }
+	    if(CSDIsQuery())
+	    {
+		CSDBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(PDialogIsQuery())
-            {
-                PDialogBreakQuery();
+	    }
+	    if(PDialogIsQuery())
+	    {
+		PDialogBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            if(FPromptIsQuery())
-            {
-                FPromptBreakQuery();
+	    }
+	    if(FPromptIsQuery())
+	    {
+		FPromptBreakQuery();
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
-            /* All dialogs not in query. */
+	    }
+	    /* All dialogs not in query */
 
 
-            /* Reset close all windows marker, which initially
+	    /* Reset close all windows marker, which initially
 	     * triggered this case.
 	     */
-            need_close_all_windows = FALSE;
+	    need_close_all_windows = FALSE;
 
 	    /* Reset still processing marker, which indicates that there
 	     * are still windows that are processing and cannot be closed.
 	     */
-            still_processing = FALSE;
+	    still_processing = FALSE;
 
 	    /* Reset has changes marker, which indicates there is atleast
 	     * one window with unsaved modified data.
@@ -421,14 +400,14 @@ gint VMATimeoutCB(gpointer data)
 	     * still processing or have changes.
 	     */
 
-	    /* Editor windows. */
-            for(i = 0; i < core_ptr->total_editors; i++)
-            {
-                editor = core_ptr->editor[i];
-                if(editor == NULL)
-                    continue;
+	    /* Editor windows */
+	    for(i = 0; i < core_ptr->total_editors; i++)
+	    {
+		editor = core_ptr->editor[i];
+		if(editor == NULL)
+		    continue;
 
-                if(editor->initialized)
+		if(editor->initialized)
 		{
 		    if(editor->processing)
 			still_processing = TRUE;
@@ -443,10 +422,10 @@ gint VMATimeoutCB(gpointer data)
 			has_changes = TRUE;
 		    }
 
-                }
-            }
+		}
+	    }
 
-	    /* Preferences window. */
+	    /* Preferences window */
 	    pref_win = core_ptr->pref_win;
 	    if((pref_win != NULL) ? pref_win->initialized : 0)
 	    {
@@ -454,36 +433,36 @@ gint VMATimeoutCB(gpointer data)
 		    still_processing = TRUE;
 	    }
 
-	    /* Print window. */
-            print_win = core_ptr->print_win;
-            if((print_win != NULL) ? print_win->initialized : 0)
-            {   
+	    /* Print window */
+	    print_win = core_ptr->print_win;
+	    if((print_win != NULL) ? print_win->initialized : 0)
+	    {   
 /*
-                if(print_win->processing)
-                    still_processing = TRUE;
+		if(print_win->processing)
+		    still_processing = TRUE;
  */
-            }  
+	    }  
 
 
 	    /* Begin checking results, to see if any windows are still
 	     * processing or have unsaved changed data.
 	     */
 
-            /* Any still processing? */
-            if(still_processing)
-            {
-                /* One or more window is still processing, cannot close
+	    /* Any still processing? */
+	    if(still_processing)
+	    {
+		/* One or more window is still processing, cannot close
 		 * now so we need to return. The next call to this
 		 * function won't close all windows since we set the
 		 * global marker for that to FALSE.
 		 */
 		DO_RETURN_CURRENT_SCHEDUAL
-            }
+	    }
 
 	    /* Any have changed data? */
 	    if(has_changes)
 	    {
-		/* Found some changed data that was not saved. */
+		/* Found some changed data that was not saved */
 		int status;
 
 		CDialogSetTransientFor(transient_for_w);
@@ -500,13 +479,13 @@ you can say yes to exit and discard those changes.",
 		    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO |
 		    CDIALOG_BTNFLAG_HELP,
 		    CDIALOG_BTNFLAG_NO
-                );
+		);
 		CDialogSetTransientFor(NULL);
 		switch(status)
 		{
 		  case CDIALOG_RESPONSE_YES:
-                  case CDIALOG_RESPONSE_YES_TO_ALL:
-                  case CDIALOG_RESPONSE_OK:
+		  case CDIALOG_RESPONSE_YES_TO_ALL:
+		  case CDIALOG_RESPONSE_OK:
 		    /* Break out of GTK main loop and remove timeout
 		     * callback to this function.
 		     */
@@ -521,14 +500,14 @@ you can say yes to exit and discard those changes.",
 	    }
 	    else
 	    {
-		/* No changed data found. */
+		/* No changed data found */
 
 		/* Break out of GTK main loop and remove timeout callback
 		 * to this function.
 		 */
 		DO_GTK_MAIN_QUIT
 
-                /* Return and do not keep schedual callback to this function. */
+		/* Return and do not keep schedual callback to this function */
 		DO_RETURN_NO_RESCHEDUAL
 	    }
 	}
@@ -538,21 +517,21 @@ you can say yes to exit and discard those changes.",
 	 */
 	all_unmapped = TRUE;
 
-	/* Editor windows. */
+	/* Editor windows */
 	for(i = 0; i < core_ptr->total_editors; i++)
-        {
-            editor = core_ptr->editor[i];
-            if(editor == NULL)
-                continue;
+	{
+	    editor = core_ptr->editor[i];
+	    if(editor == NULL)
+		continue;
 
-            if(editor->initialized && editor->map_state)
+	    if(editor->initialized && editor->map_state)
 	    {
 		all_unmapped = FALSE;
 		break;
 	    }
-        }
+	}
 
-	/* Preferanecs window. */
+	/* Preferanecs window */
 	pref_win = core_ptr->pref_win;
 	if((pref_win != NULL) ? pref_win->initialized : 0)
 	{
@@ -572,18 +551,18 @@ you can say yes to exit and discard those changes.",
 	     */
 	    DO_GTK_MAIN_QUIT
 
-	    /* Return and do not keep schedual callback to this function. */
+	    /* Return and do not keep schedual callback to this function */
 	    DO_RETURN_NO_RESCHEDUAL
 	}
 
-	/* Manage print jobs. */
+	/* Manage print jobs */
 	for(i = 0; i < core_ptr->total_print_jobs; i++)
 	{
 	    pj = core_ptr->print_job[i];
 	    if(pj == NULL)
 		continue;
 
-	    /* Manage this print job. */
+	    /* Manage this print job */
 	    if(!PrintJobManage(pj))
 	    {
 		/* Print job manage returned false, implying it's done
@@ -614,43 +593,37 @@ you can say yes to exit and discard those changes.",
  */
 gint VMABackupTimeoutCB(gpointer data)
 {
-        static gbool reenterant = FALSE;
 	gint i;
 	int min, max, new_index_highest;
 	ma_editor_struct *editor;
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return(FALSE);
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return(FALSE);
 
-        if(reenterant)
-            return(TRUE);
-        else
-            reenterant = TRUE;
-
-	/* Itterate through each editor. */
-        for(i = 0; i < core_ptr->total_editors; i++)
-        {
-            editor = core_ptr->editor[i];
-            if(editor == NULL)
-                continue;
+	/* Itterate through each editor */
+	for(i = 0; i < core_ptr->total_editors; i++)
+	{
+	    editor = core_ptr->editor[i];
+	    if(editor == NULL)
+		continue;
 
 	    /* Skip this editor if it is not initialized, is currently
 	     * processing, or does not have data with an assoicated 
 	     * filename.
 	     */
 	    if(!editor->initialized || editor->processing ||
-               (editor->loaded_filename == NULL)
+	       (editor->loaded_filename == NULL)
 	    )
 		continue;
 
-	    /* Mark as processing. */
+	    /* Mark as processing */
 	    EditorSetBusy(editor);
 	    editor->processing = TRUE;
 
 	    VMAStatusBarMessage(editor->sb, "Automatic backup in progress...");
 	    VMAStatusBarProgress(editor->sb, 0.0);
 
-	    /* Make backup. */
+	    /* Make backup */
 	    min = 1;
 	    max = VMACFGItemListGetValueI(
 		option, VMA_CFG_PARM_BACKUP_MAX
@@ -663,51 +636,49 @@ gint VMABackupTimeoutCB(gpointer data)
 		min, max,
 		(new_index_highest) ?
 		    VMA_BACKUP_ORDER_HL : VMA_BACKUP_ORDER_LH,
-		1		/* Can remove overflow. */
+		1		/* Can remove overflow */
 	    ) == VMA_BACKUP_SUCCESS)
 	    {
 		VMAStatusBarMessage(editor->sb, "Automatic backup done");
 	    }
 	    else
 	    {
-                VMAStatusBarMessage(editor->sb, "Automatic backup failed!");
+		VMAStatusBarMessage(editor->sb, "Automatic backup failed!");
 	    }
 
 	    VMAStatusBarProgress(editor->sb, 0.0);
 
-            /* Mark as done processing. */
-            EditorSetReady(editor);
-            editor->processing = FALSE;
+	    /* Mark as done processing */
+	    EditorSetReady(editor);
+	    editor->processing = FALSE;
  
-	    /* Need to update menus on editor. */
+	    /* Need to update menus on editor */
 	    EditorUpdateMenus(editor);
 	    EditorUpdateAllViewMenus(editor);
-        }
+	}
 
 
-        /* Schedual next backup timeout callback for this function, since
-         * this function always returns FALSE past this point.
-         */
-        i = VMACFGItemListGetValueI(option, VMA_CFG_PARM_BACKUP_PERIODIC_INT);
-        if(i > 0)
-        {
-            core_ptr->backup_toid = gtk_timeout_add(
-                i * 60 * 1000,  /* Convert to milliseconds. */
-                (GtkFunction)VMABackupTimeoutCB,
-                (gpointer)core_ptr
-            );
-        }
-        else
-        {
-            core_ptr->backup_toid = (guint)-1;
-        }
+	/* Schedual next backup timeout callback for this function, since
+	 * this function always returns FALSE past this point.
+	 */
+	i = VMACFGItemListGetValueI(option, VMA_CFG_PARM_BACKUP_PERIODIC_INT);
+	if(i > 0)
+	{
+	    core_ptr->backup_toid = gtk_timeout_add(
+		(gulong)i * 60l * 1000l,  /* Convert to milliseconds */
+		VMABackupTimeoutCB, core_ptr
+	    );
+	}
+	else
+	{
+	    core_ptr->backup_toid = (guint)-1;
+	}
 
-	reenterant = FALSE;
-        /* Return FALSE, since a NEW timeout callback has just been
-         * schedualed for this function by this function so we can return
-         * FALSE indicating not to call this function again for the
-         * previous (old) timeout.
-         */
+	/* Return FALSE, since a NEW timeout callback has just been
+	 * schedualed for this function by this function so we can return
+	 * FALSE indicating not to call this function again for the
+	 * previous (old) timeout.
+	 */
 	return(FALSE);
 }
 
@@ -716,29 +687,29 @@ gint VMABackupTimeoutCB(gpointer data)
  */
 gint VMAPluginManageTimeoutCB(gpointer data)
 {
-        static gbool reenterant = FALSE;
+	static gbool reenterant = FALSE;
 	gbool init_called = FALSE;
 	gint i;
 	ma_editor_struct *editor;
 	vma_plugin_struct *plugin_ptr;
 	VPI_PROTO_RETURN_MANAGE (*manage_func)(VPI_PROTO_INPUT_MANAGE);
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return(FALSE);
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return(FALSE);
 
-        if(reenterant)
-            return(TRUE);
-        else
-            reenterant = TRUE;
+	if(reenterant)
+	    return(TRUE);
+	else
+	    reenterant = TRUE;
 
-	/* Itterate through each plug-in. */
+	/* Itterate through each plug-in */
 	for(i = 0; i < core_ptr->total_plugins; i++)
 	{
 	    plugin_ptr = core_ptr->plugin[i];
 	    if((plugin_ptr == NULL) ? 1 : (plugin_ptr->handle == NULL))
 		continue;
 
-	    /* Skip plug-in if it is busy processing. */
+	    /* Skip plug-in if it is busy processing */
 	    if(plugin_ptr->processing)
 		continue;
 
@@ -766,7 +737,7 @@ gint VMAPluginManageTimeoutCB(gpointer data)
 		    vpi_init_struct v;
 
 
-		    /* Set up initialize value structure. */
+		    /* Set up initialize value structure */
 		    v.flags = (VPI_FLAG_INIT_START_TYPE |
 			VPI_FLAG_INIT_FILENAME |
 			VPI_FLAG_INIT_ARGC | VPI_FLAG_INIT_ARGV
@@ -778,30 +749,30 @@ gint VMAPluginManageTimeoutCB(gpointer data)
 		    v.argc = 0;
 		    v.argv = NULL;
 
-		    /* Call plug-in's initialize function. */
+		    /* Call plug-in's initialize function */
 		    plugin_ptr->processing = 1;
 		    status = init_func((vpi_id *)plugin_ptr, &v);
 		    init_called = TRUE;
-                    plugin_ptr->processing = 0;
+		    plugin_ptr->processing = 0;
 
 
-		    /* Deallocate initialize value structure members. */
+		    /* Deallocate initialize value structure members */
 		    g_free(v.filename);
 		    for(n = 0; n < v.argc; n++)
 			g_free(v.argv[n]);
 		    g_free(v.argv);
 
 		    /* Plug-in's initialization function return false? */
-                    if(!status)
-                    {
-                        /* Initialization failed. */
-                        VPIDisable(plugin_ptr);
-                        continue;
-                    }
+		    if(!status)
+		    {
+			/* Initialization failed */
+			VPIDisable(plugin_ptr);
+			continue;
+		    }
 		}
 	    }	/* Need to call initialization routine for plugin? */
 
-	    /* Call management function. */
+	    /* Call management function */
 	    manage_func = plugin_ptr->manage;
 	    if(manage_func != NULL)
 	    {
@@ -809,25 +780,25 @@ gint VMAPluginManageTimeoutCB(gpointer data)
 		vpi_manage_struct v;
 
 
-                /* Set up manage value structure. */
+		/* Set up manage value structure */
 		v.flags = VPI_FLAG_MANAGE_CLIENT_DATA;
 		v.client_data = plugin_ptr->client_data;
 
-		/* Call plug-in's manage function. */
-                plugin_ptr->processing = 1;
-                status = manage_func((vpi_id *)plugin_ptr, &v);
-                plugin_ptr->processing = 0;
+		/* Call plug-in's manage function */
+		plugin_ptr->processing = 1;
+		status = manage_func((vpi_id *)plugin_ptr, &v);
+		plugin_ptr->processing = 0;
 
-		/* Deallocate manage value structure members. */
-/* None. */
+		/* Deallocate manage value structure members */
+/* None */
 
 		/* Plug-in's manage function returned false? */
-                if(!status)
-                {
-                    /* Manage failed. */
-                    VPIDisable(plugin_ptr);
-                    continue;
-                }
+		if(!status)
+		{
+		    /* Manage failed */
+		    VPIDisable(plugin_ptr);
+		    continue;
+		}
 	    }
 
 	}
@@ -838,7 +809,7 @@ gint VMAPluginManageTimeoutCB(gpointer data)
 	 */
 	if(init_called)
 	{
-	    /* Editor render menu items. */
+	    /* Editor render menu items */
 	    for(i = 0; i < core_ptr->total_editors; i++)
 	    {
 		editor = core_ptr->editor[i];
@@ -857,22 +828,22 @@ gint VMAPluginManageTimeoutCB(gpointer data)
 	}
 
 
-        /* Schedual next plugin timeout callback for this function, since
-         * this function always returns FALSE past this point.
-         */
-        core_ptr->plugin_manage_toid = gtk_timeout_add(
-            50,
-            (GtkFunction)VMAPluginManageTimeoutCB,
-            (gpointer)core_ptr
-        );
+	/* Schedual next plugin timeout callback for this function, since
+	 * this function always returns FALSE past this point.
+	 */
+	core_ptr->plugin_manage_toid = gtk_timeout_add(
+	    50,
+	    (GtkFunction)VMAPluginManageTimeoutCB,
+	    (gpointer)core_ptr
+	);
 
-        reenterant = FALSE;
-        /* Return FALSE, since a NEW timeout callback has just been
-         * schedualed for this function by this function so we can return
-         * FALSE indicating not to call this function again for the
-         * previous (old) timeout.
-         */
-        return(FALSE);
+	reenterant = FALSE;
+	/* Return FALSE, since a NEW timeout callback has just been
+	 * schedualed for this function by this function so we can return
+	 * FALSE indicating not to call this function again for the
+	 * previous (old) timeout.
+	 */
+	return(FALSE);
 }
 
 
@@ -887,10 +858,10 @@ void VMAShowTipOfDayNextTimeToggleCB(GtkWidget *widget, gpointer data)
 	if((tb == NULL) || (core_ptr == NULL))
 	    return;
 
-	/* Check if toggle button is active. */
+	/* Check if toggle button is active */
 	ui8 = ((tb->active) ? 1 : 0);
 
-	/* Record value in configuration. */
+	/* Record value in configuration */
 	VMACFGItemListMatchSetValue(
 	    option, VMA_CFG_PARM_SHOW_TIPOFDAY,
 	    &ui8, TRUE
@@ -912,7 +883,7 @@ void VMANewEditor(vma_core_struct *core_ptr)
 	if(core_ptr == NULL)
 	    return;
 
-        /* Check if one is already initailized and unmapped. */
+	/* Check if one is already initailized and unmapped */
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    editor = core_ptr->editor[i];
@@ -924,43 +895,43 @@ void VMANewEditor(vma_core_struct *core_ptr)
 	}
 	if(i < core_ptr->total_editors)
 	{
-	    /* Found one initialized but not mapped. */
+	    /* Found one initialized but not mapped */
 	    new_editor = core_ptr->editor[i];
 	}
 	else
 	{
-	    /* Need to create a new one. */
+	    /* Need to create a new one */
 
-	    /* Check if a pointer in the array is NULL. */
+	    /* Check if a pointer in the array is NULL */
 	    for(i = 0; i < core_ptr->total_editors; i++)
-            {
+	    {
 		if(core_ptr->editor[i] == NULL)
 		    break;
 	    }
 	    if(i < core_ptr->total_editors)
 	    {
-		/* Found a NULL pointer i, use it. */
-                core_ptr->editor[i] = new_editor = EditorCreate(core_ptr);
+		/* Found a NULL pointer i, use it */
+		core_ptr->editor[i] = new_editor = EditorCreate(core_ptr);
 	    }
 	    else
 	    {
-		/* Need to allocate more pointers. */
+		/* Need to allocate more pointers */
 		i = core_ptr->total_editors;
 		core_ptr->total_editors++;
-                core_ptr->editor = (ma_editor_struct **)realloc(
-                    core_ptr->editor,  
-                    core_ptr->total_editors * sizeof(ma_editor_struct *)
-                );
-                if(core_ptr->editor == NULL)
-                {
-                    core_ptr->total_editors = 0;
-                }
-                else
-                {
-                    core_ptr->editor[i] = new_editor = EditorCreate(core_ptr);
+		core_ptr->editor = (ma_editor_struct **)realloc(
+		    core_ptr->editor,  
+		    core_ptr->total_editors * sizeof(ma_editor_struct *)
+		);
+		if(core_ptr->editor == NULL)
+		{
+		    core_ptr->total_editors = 0;
 		}
-            }
-        }
+		else
+		{
+		    core_ptr->editor[i] = new_editor = EditorCreate(core_ptr);
+		}
+	    }
+	}
  
 	/* Got new editor? */
 	if(new_editor != NULL)
@@ -979,8 +950,8 @@ void VMANewEditor(vma_core_struct *core_ptr)
 void VMANewEditorCB(GtkWidget *widget, gpointer data)
 {
 	vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	if(core_ptr == NULL)
+	    return;
 
 	VMANewEditor(core_ptr);
 
@@ -992,16 +963,16 @@ void VMANewEditorCB(GtkWidget *widget, gpointer data)
  */
 void VMAScratchPadMapCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
 	if(core_ptr->scratch_pad != NULL)
 	{
-	    /* Update scratch pad's target editors list. */
+	    /* Update scratch pad's target editors list */
 	    ScratchPadUpdateTargetEditors(core_ptr->scratch_pad);
 
-	    /* Map scratch pad. */
+	    /* Map scratch pad */
 	    ScratchPadMap(core_ptr->scratch_pad);
 	}
 
@@ -1019,13 +990,13 @@ void VMAAboutDialogMapCB(GtkWidget *widget, gpointer data)
 	if(core_ptr == NULL)
 	    return;
 
-	/* Get pointer to about dialot. */
+	/* Get pointer to about dialot */
 	ad = core_ptr->about_dialog;
 
 	/* About dialog not initialized yet? */
 	if(ad == NULL)
 	{
-	    /* Initialize about dialot now. */
+	    /* Initialize about dialot now */
 	    core_ptr->about_dialog = ad = AboutDialogNew(core_ptr);
 	}
 
@@ -1033,7 +1004,7 @@ void VMAAboutDialogMapCB(GtkWidget *widget, gpointer data)
 	if(ad == NULL)
 	    return;
 
-	/* Map the about dialog. */
+	/* Map the about dialog */
 	AboutDialogMap(ad);
 
 	return;
@@ -1046,7 +1017,7 @@ void VMAAboutDialogMapCB(GtkWidget *widget, gpointer data)
 void VMAHelpContentsCB(GtkWidget *widget, gpointer data)
 {
 	vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
+	if(core_ptr == NULL)
 	    return;
 
 	VMAHelpFile(
@@ -1063,15 +1034,15 @@ void VMAHelpContentsCB(GtkWidget *widget, gpointer data)
  */
 void VMAHelpTutorialCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
-        VMAHelpFile(
-            core_ptr,
-            VMA_HELP_FILE_TUTORIALS,
-            TRUE
-        );
+	VMAHelpFile(
+	    core_ptr,
+	    VMA_HELP_FILE_TUTORIALS,
+	    TRUE
+	);
 
 	return;
 }
@@ -1081,17 +1052,17 @@ void VMAHelpTutorialCB(GtkWidget *widget, gpointer data)
  */
 void VMAHelpViewingCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
-        VMAHelpFile(
-            core_ptr,
-            VMA_HELP_FILE_VIEWING,
-            TRUE
-        );
+	VMAHelpFile(
+	    core_ptr,
+	    VMA_HELP_FILE_VIEWING,
+	    TRUE
+	);
 
-        return;
+	return;
 }
 
 /*
@@ -1099,17 +1070,17 @@ void VMAHelpViewingCB(GtkWidget *widget, gpointer data)
  */
 void VMAHelpKeyboardCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
-        VMAHelpFile( 
-            core_ptr,
-            VMA_HELP_FILE_KEYBOARD,
-            TRUE
-        );
+	VMAHelpFile( 
+	    core_ptr,
+	    VMA_HELP_FILE_KEYBOARD,
+	    TRUE
+	);
 
-        return;
+	return;
 }
 
 /*
@@ -1117,17 +1088,17 @@ void VMAHelpKeyboardCB(GtkWidget *widget, gpointer data)
  */
 void VMAHelpV3DFormatCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
-        VMAHelpFile(
-            core_ptr,
-            VMA_HELP_FILE_V3D_FORMAT,
-            TRUE
-        );
+	VMAHelpFile(
+	    core_ptr,
+	    VMA_HELP_FILE_V3D_FORMAT,
+	    TRUE
+	);
 
-        return;
+	return;
 }
 
 /*
@@ -1135,17 +1106,17 @@ void VMAHelpV3DFormatCB(GtkWidget *widget, gpointer data)
  */
 void VMAHelpPluginsCB(GtkWidget *widget, gpointer data)
 {
-        vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	vma_core_struct *core_ptr = (vma_core_struct *)data;
+	if(core_ptr == NULL)
+	    return;
 
-        VMAHelpFile(
-            core_ptr,
-            VMA_HELP_FILE_PLUGINS,
-            TRUE
-        );
+	VMAHelpFile(
+	    core_ptr,
+	    VMA_HELP_FILE_PLUGINS,
+	    TRUE
+	);
 
-        return;
+	return;
 }
 
 
@@ -1157,8 +1128,8 @@ void VMATipOfDayCB(GtkWidget *widget, gpointer data)
 	static const char *tod_msglist[] = VMA_MSGLIST_TOD_MESSAGE_LIST;
 	gbool show_tip_next_time;
 	vma_core_struct *core_ptr = (vma_core_struct *)data;
-        if(core_ptr == NULL)
-            return;
+	if(core_ptr == NULL)
+	    return;
 
 	show_tip_next_time = (VMACFGItemListGetValueI(
 	    option, VMA_CFG_PARM_SHOW_TIPOFDAY
@@ -1211,11 +1182,11 @@ void VMARecordFBPath(
 	if((new_path == NULL) || (rec_path == NULL))
 	    return;
 
-	/* New path must be absolute. */
+	/* New path must be absolute */
 	if((*new_path) != DIR_DELIMINATOR)
 	    return;
 
-	/* Copy new path to tmp path. */
+	/* Copy new path to tmp path */
 	strncpy(tmp_path, new_path, PATH_MAX + NAME_MAX);
 	tmp_path[PATH_MAX + NAME_MAX - 1] = '\0';
 
@@ -1226,7 +1197,7 @@ void VMARecordFBPath(
 	    {
 		if(!S_ISDIR(stat_buf.st_mode))
 		{
-		    /* Not a dir and must be a dir, so get its parent. */
+		    /* Not a dir and must be a dir, so get its parent */
 		    int len = strlen(tmp_path);
 		    char *strptr;
 
@@ -1245,11 +1216,11 @@ void VMARecordFBPath(
 	    }
 	}
 
-	/* Record path. */
+	/* Record path */
 	strncpy(
 	    rec_path,
 	    tmp_path,
-	    PATH_MAX	/* Just PATH_MAX bytes. */
+	    PATH_MAX	/* Just PATH_MAX bytes */
 	);
 	rec_path[PATH_MAX  - 1] = '\0';
 
